(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    124730,       2681]
NotebookOptionsPosition[    113945,       2549]
NotebookOutlinePosition[    114382,       2566]
CellTagsIndexPosition[    114339,       2563]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["General functions", "Section",
 CellChangeTimes->{{3.9292017673387065`*^9, 
  3.929201775727317*^9}},ExpressionUUID->"e59f7094-0396-445a-8b16-\
6c020d74b19f"],

Cell["\<\
Function for creating a honeycomb lattice of linear dimensions \
\[OpenCurlyDoubleQuote]nx\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]ny\[CloseCurlyDoubleQuote] with periodic boundary \
conditions; the output is a \[OpenCurlyDoubleQuote]Lattice\
\[CloseCurlyDoubleQuote] object to be used by other functions below.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.929202029917598*^9}, {3.9296323822983046`*^9, 
   3.9296324633717704`*^9}, {3.9296324956766872`*^9, 3.929632502190921*^9}, 
   3.9296339076636667`*^9, {3.930058081509387*^9, 
   3.9300580864985485`*^9}},ExpressionUUID->"36726221-9586-4d1c-8fe5-\
a0003a3b7f73"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CreateLattice", "[", 
   RowBox[{"nx_", ",", "ny_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "m", ",", "n", ",", "S", ",", "P", ",", "ix", ",", "iy", ",", "PP", ",", 
      "B", ",", "i", ",", "p", ",", "j", ",", "pp", ",", "ii"}], "}"}], ",", 
    RowBox[{
     RowBox[{"m", "=", 
      RowBox[{"nx", " ", "ny"}]}], ";", 
     RowBox[{"n", "=", 
      RowBox[{"2", "m"}]}], ";", 
     RowBox[{"S", "=", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"ConstantArray", "[", 
         RowBox[{"1", ",", "m"}], "]"}], ",", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"2", ",", "m"}], "]"}]}], "]"}]}], ";", 
     RowBox[{"P", "=", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", "n"}], "]"}]}], ";", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"ix", "=", "0"}], ",", 
       RowBox[{"ix", "<", "nx"}], ",", 
       RowBox[{"ix", "++"}], ",", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"iy", "=", "0"}], ",", 
         RowBox[{"iy", "<", "ny"}], ",", 
         RowBox[{"iy", "++"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"P", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"ny", " ", "ix"}], "+", "iy", "+", "1"}], "]"}], "]"}], 
           "=", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"ix", ",", "iy"}], "}"}], ".", "R"}]}], ";", 
          RowBox[{
           RowBox[{"P", "[", 
            RowBox[{"[", 
             RowBox[{"m", "+", 
              RowBox[{"ny", " ", "ix"}], "+", "iy", "+", "1"}], "]"}], "]"}], 
           "=", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{"ix", ",", "iy"}], "}"}], ".", "R"}], "+", 
            RowBox[{"r", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}]}]}]}], "]"}]}], "]"}], ";", 
     RowBox[{"PP", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"P", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "-", 
         RowBox[{
          RowBox[{"Power", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", 
            RowBox[{"S", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], 
          RowBox[{"r", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}]}], ";", 
     RowBox[{"B", "=", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "3"}], "}"}]}], "]"}]}], ";", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "<=", "n"}], ",", 
       RowBox[{"i", "++"}], ",", 
       RowBox[{
        RowBox[{"p", "=", 
         RowBox[{"P", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"j", "=", "1"}], ",", 
          RowBox[{"j", "<=", "3"}], ",", 
          RowBox[{"j", "++"}], ",", 
          RowBox[{
           RowBox[{"pp", "=", 
            RowBox[{"PP", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ";", 
           RowBox[{"pp", "=", 
            RowBox[{"pp", "-", 
             RowBox[{
              RowBox[{"Floor", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"G", ".", "pp"}], ")"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "/", "ny"}], "]"}], "ny", 
              " ", 
              RowBox[{"R", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}]}], ";", 
           RowBox[{"pp", "=", 
            RowBox[{"pp", "-", 
             RowBox[{
              RowBox[{"Floor", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"G", ".", "pp"}], ")"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "/", "nx"}], "]"}], "nx", 
              " ", 
              RowBox[{"R", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}]}]}], ";", 
           RowBox[{"ii", "=", 
            RowBox[{"Position", "[", 
             RowBox[{"P", ",", "pp"}], "]"}]}], ";", 
           RowBox[{
            RowBox[{"B", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
            RowBox[{"ii", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}]}], "]"}]}]}], "]"}], 
     ";", 
     RowBox[{"{", 
      RowBox[{"m", ",", "S", ",", "P", ",", "PP", ",", "B"}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.9291886993156223`*^9, 3.9291887771255927`*^9}, {
  3.929188811180072*^9, 3.9291888369551277`*^9}, {3.9291889127187023`*^9, 
  3.9291890168972254`*^9}, {3.9291892070006466`*^9, 3.929189219810171*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"32fd29f6-0588-42c9-b899-7cb1a9400ecc"],

Cell["\<\
Function for plotting the honeycomb lattice; \[OpenCurlyDoubleQuote]L\
\[CloseCurlyDoubleQuote] is the \[OpenCurlyDoubleQuote]Lattice\
\[CloseCurlyDoubleQuote] object created by the first function above, while \
\[OpenCurlyDoubleQuote]p\[CloseCurlyDoubleQuote] is the picture size and \
\[OpenCurlyDoubleQuote]f\[CloseCurlyDoubleQuote] is the font size for site \
labels (there are no site labels if \[OpenCurlyDoubleQuote]f\
\[CloseCurlyDoubleQuote] is set to zero); labels for sites in sublattice A \
and B are in black and red color, respectively, while translated images of \
sites connected by periodic boundary conditions are in blue color.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292021948944993`*^9}, {3.929202566275963*^9, 
   3.9292026274179935`*^9}, 3.9296339187234616`*^9, {3.930058114523168*^9, 
   3.9300582122343526`*^9}, {3.930058808050514*^9, 
   3.930058809737753*^9}},ExpressionUUID->"96935deb-e85c-4f39-9e18-\
46b7dcab3483"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotLattice", "[", 
   RowBox[{"L_", ",", "p_", ",", "f_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", "S", ",", "P", ",", "PP", ",", "B", ",", "n"}], "}"}], 
    ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", "S", ",", "P", ",", "PP", ",", "B"}], "}"}], "=", 
      "L"}], ";", 
     RowBox[{"n", "=", 
      RowBox[{"2", "m"}]}], ";", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"Black", ",", 
               RowBox[{"Thickness", "[", "0.0005", "]"}], ",", 
               RowBox[{"Line", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"P", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], ",", 
                  RowBox[{"PP", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}], "]"}]}], 
              "}"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Length", "[", 
                 RowBox[{"Position", "[", 
                  RowBox[{"P", ",", 
                   RowBox[{"PP", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "]"}], "]"}], "==",
                 "0"}], ",", 
               RowBox[{"{", 
                RowBox[{"Blue", ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{
                   RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
                    RowBox[{"PP", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "]"}], ",", 
                   RowBox[{"Background", "->", "White"}]}], "]"}]}], "}"}]}], 
              "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"S", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "==", "1"}], ",", "Black", 
               ",", "Red"}], "]"}], ",", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{"i", ",", 
                 RowBox[{"P", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
               RowBox[{"Background", "->", "White"}]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}], "}"}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", "Times"}], ",", 
          RowBox[{"FontSize", "\[Rule]", "f"}]}], "}"}]}], ",", 
       RowBox[{"ImageSize", "->", "p"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.929189051732794*^9, 3.929189098924832*^9}, {
   3.9291891373690634`*^9, 3.9291891602541895`*^9}, {3.929189305727453*^9, 
   3.9291893398913016`*^9}, {3.9291893889266543`*^9, 
   3.9291893982370024`*^9}, {3.9291900306423826`*^9, 
   3.9291900326619616`*^9}, {3.9291900957841988`*^9, 
   3.9291901074845724`*^9}, {3.929191062255475*^9, 3.9291910623648663`*^9}, {
   3.92919654707364*^9, 3.929196560555401*^9}, {3.9291968581027794`*^9, 
   3.92919688595573*^9}, 3.929198227017454*^9, {3.9291982842852116`*^9, 
   3.9291982843633475`*^9}, {3.929198323244963*^9, 3.929198325838105*^9}, 
   3.9291985675695815`*^9, {3.929198626402439*^9, 3.9291986265430365`*^9}, 
   3.9292003700714493`*^9, 3.9292004229808974`*^9, {3.9292005040332146`*^9, 
   3.9292005259355745`*^9}, {3.9292005588283677`*^9, 3.929200559599168*^9}, {
   3.9292006043831806`*^9, 3.9292006232085457`*^9}, {3.929200672642657*^9, 
   3.9292007068281536`*^9}, {3.929200939447936*^9, 3.9292009396170406`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"75875ff0-dc5d-4cd7-ba8d-c3f9e2773877"],

Cell["\<\
Function for plotting the honeycomb lattice with gauge fields on bonds and \
gauge fluxes at hexagons; \[OpenCurlyDoubleQuote]L\[CloseCurlyDoubleQuote] is \
the \[OpenCurlyDoubleQuote]Lattice\[CloseCurlyDoubleQuote] object created by \
the first function above, \[OpenCurlyDoubleQuote]U\[CloseCurlyDoubleQuote] is \
an \[OpenCurlyDoubleQuote]m\[CloseCurlyDoubleQuote] x 3 matrix of the gauge \
fields around the \[OpenCurlyDoubleQuote]m\[CloseCurlyDoubleQuote] sites on \
sublattice A (with the 3 elements in each row corresponding to x=1, y=2, and \
z=3 bonds, respectively), while \[OpenCurlyDoubleQuote]p\
\[CloseCurlyDoubleQuote] is the picture size and \[OpenCurlyDoubleQuote]f\
\[CloseCurlyDoubleQuote] is the font size for site labels (there are no site \
labels if \[OpenCurlyDoubleQuote]f\[CloseCurlyDoubleQuote] is set to zero); \
nontrivial gauge fields (u = -1) are marked by thick lines and excited gauge \
fluxes (W = -1) are denoted by crosses.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.9292027029783583`*^9, 
   3.9292027244576616`*^9}, {3.9296322911790733`*^9, 3.929632312221137*^9}, {
   3.929632547836454*^9, 3.9296325532101917`*^9}, 
   3.929633920738719*^9},ExpressionUUID->"211ddf56-a43e-45e2-890f-\
d931bba36b17"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotGauge", "[", 
   RowBox[{"L_", ",", "U_", ",", "p_", ",", "f_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "m", ",", "S", ",", "P", ",", "PP", ",", "B", ",", "n", ",", "a"}], 
     "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", "S", ",", "P", ",", "PP", ",", "B"}], "}"}], "=", 
      "L"}], ";", 
     RowBox[{"n", "=", 
      RowBox[{"2", "m"}]}], ";", 
     RowBox[{"a", "=", "0.3"}], ";", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"U", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"S", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "==", "1"}], ",", "i", 
                    ",", 
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "]"}], ",", 
                   "j"}], "]"}], "]"}], "!=", "0"}], ",", 
               RowBox[{"{", 
                RowBox[{"Black", ",", 
                 RowBox[{"Thickness", "[", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"U", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"S", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "==", "1"}], ",", "i", 
                    ",", 
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "]"}], ",", 
                    "j"}], "]"}], "]"}], ">", "0"}], ",", "0.0005", ",", 
                    "0.005"}], "]"}], "]"}], ",", 
                 RowBox[{"Line", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"P", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"PP", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}], "]"}]}], 
                "}"}]}], "]"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Length", "[", 
                 RowBox[{"Position", "[", 
                  RowBox[{"P", ",", 
                   RowBox[{"PP", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "]"}], "]"}], "==",
                 "0"}], ",", 
               RowBox[{"{", 
                RowBox[{"Blue", ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{
                   RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
                    RowBox[{"PP", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "]"}], ",", 
                   RowBox[{"Background", "->", "White"}]}], "]"}]}], "}"}]}], 
              "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"S", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "==", "1"}], ",", "Black", 
               ",", "Red"}], "]"}], ",", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{"i", ",", 
                 RowBox[{"P", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
               RowBox[{"Background", "->", "White"}]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "1"}], "]"}], "]"}], 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", "3"}], "]"}], 
                    "]"}], ",", "3"}], "]"}], "]"}], 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", "3"}], "]"}], 
                    "]"}], ",", "2"}], "]"}], "]"}], 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", "3"}], "]"}], 
                    "]"}], ",", "1"}], "]"}], "]"}], 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", "3"}], "]"}], 
                    "]"}], ",", "3"}], "]"}], "]"}], 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "<", "0"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Line", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"P", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "-", 
                    RowBox[{"r", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "+", 
                    RowBox[{"a", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "1"}], "}"}]}]}], ",", 
                    RowBox[{
                    RowBox[{"P", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "-", 
                    RowBox[{"r", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "+", 
                    RowBox[{"a", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}]}], "}"}]}]}]}], "}"}], "]"}], ",", 
                 RowBox[{"Line", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"P", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "-", 
                    RowBox[{"r", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "+", 
                    RowBox[{"a", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}], "}"}]}]}], ",", 
                    RowBox[{
                    RowBox[{"P", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "-", 
                    RowBox[{"r", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "+", 
                    RowBox[{"a", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}]}], "}"}], 
                  "]"}]}], "}"}]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "m"}], "}"}]}], "]"}]}], "}"}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", "Times"}], ",", 
          RowBox[{"FontSize", "\[Rule]", "f"}]}], "}"}]}], ",", 
       RowBox[{"ImageSize", "->", "p"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.929189051732794*^9, 3.929189098924832*^9}, {
   3.9291891373690634`*^9, 3.9291891602541895`*^9}, {3.929189305727453*^9, 
   3.9291893398913016`*^9}, {3.9291893889266543`*^9, 
   3.9291893982370024`*^9}, {3.9291900306423826`*^9, 
   3.9291900326619616`*^9}, {3.9291900957841988`*^9, 
   3.9291901074845724`*^9}, {3.929190467246254*^9, 3.929190485320138*^9}, {
   3.929190540354087*^9, 3.9291905709094057`*^9}, {3.9291906338633585`*^9, 
   3.929190783218895*^9}, {3.929190853186833*^9, 3.9291909217488556`*^9}, {
   3.929190963426565*^9, 3.9291909771889505`*^9}, {3.9291910088207283`*^9, 
   3.9291910610682573`*^9}, {3.929195403584087*^9, 3.9291954929068155`*^9}, {
   3.929196549604295*^9, 3.929196561633274*^9}, {3.929196859789886*^9, 
   3.9291968873458786`*^9}, 3.929198228142149*^9, {3.9291982858005133`*^9, 
   3.9291982858786163`*^9}, {3.929198324588275*^9, 3.929198327790615*^9}, 
   3.9291985689911585`*^9, {3.9291986291362085`*^9, 3.9291986295110836`*^9}, {
   3.9292009385296307`*^9, 3.9292010669497166`*^9}, {3.929201281326377*^9, 
   3.9292012834001136`*^9}, 3.9300598303661084`*^9},
 CellLabel->"In[3]:=",ExpressionUUID->"5248ee17-1150-4560-94b5-ffb6ac032b00"],

Cell["\<\
Function for computing the fermion eigenmodes of the Kitaev model in a given \
flux sector; \[OpenCurlyDoubleQuote]L\[CloseCurlyDoubleQuote] is the \
\[OpenCurlyDoubleQuote]Lattice\[CloseCurlyDoubleQuote] object created by the \
first function above, \[OpenCurlyDoubleQuote]U\[CloseCurlyDoubleQuote] is an \
\[OpenCurlyDoubleQuote]m\[CloseCurlyDoubleQuote] x 3 matrix of the gauge \
fields around the \[OpenCurlyDoubleQuote]m\[CloseCurlyDoubleQuote] sites on \
sublattice A (with the 3 elements in each row corresponding to x=1, y=2, and \
z=3 bonds, respectively), while \[OpenCurlyDoubleQuote]J\
\[CloseCurlyDoubleQuote] contains the three Kitaev coupling strengths on x=1, \
y=2, and z=3 bonds, respectively, and \[OpenCurlyDoubleQuote]K\
\[CloseCurlyDoubleQuote] is the strength of the three-spin coupling that \
breaks time-reversal symmetry; the output contains eigenvalues \
\[OpenCurlyDoubleQuote]E0\[CloseCurlyDoubleQuote] (i.e., mode energies) and \
eigenvectors \[OpenCurlyDoubleQuote]V0\[CloseCurlyDoubleQuote] (i.e., wave \
functions in real space).\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.929202890074894*^9}, {
   3.929632344088665*^9, 3.9296323499309025`*^9}, {3.9296325414003334`*^9, 
   3.9296325448059235`*^9}, 3.929633924690919*^9, {3.9300590322759223`*^9, 
   3.930059033416277*^9}},ExpressionUUID->"b81ed4c1-e517-4997-86b7-\
fe878998b837"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FermionModes", "[", 
   RowBox[{"L_", ",", "U_", ",", "J_", ",", "K_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "m", ",", "S", ",", "P", ",", "PP", ",", "B", ",", "n", ",", "H", ",", 
      "i", ",", "j", ",", "ii", ",", "k", ",", "iii", ",", "S0", ",", "E0", 
      ",", "V0", ",", "P0"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", "S", ",", "P", ",", "PP", ",", "B"}], "}"}], "=", 
      "L"}], ";", 
     RowBox[{"n", "=", 
      RowBox[{"2", "m"}]}], ";", 
     RowBox[{"H", "=", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}], ";", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "<=", "n"}], ",", 
       RowBox[{"i", "++"}], ",", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "<=", "3"}], ",", 
         RowBox[{"j", "++"}], ",", 
         RowBox[{
          RowBox[{"ii", "=", 
           RowBox[{"B", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ";", 
          RowBox[{
           RowBox[{"H", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "ii"}], "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"Power", "[", 
             RowBox[{
              RowBox[{"-", "1"}], ",", 
              RowBox[{"S", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}], 
            RowBox[{"U", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"S", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "==", "1"}], ",", "i", ",",
                  "ii"}], "]"}], ",", "j"}], "]"}], "]"}], 
            RowBox[{"J", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}]}], ";", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"k", "=", "1"}], ",", 
            RowBox[{"k", "<=", "3"}], ",", 
            RowBox[{"k", "++"}], ",", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"k", "!=", "j"}], ",", 
              RowBox[{
               RowBox[{"iii", "=", 
                RowBox[{"B", "[", 
                 RowBox[{"[", 
                  RowBox[{"ii", ",", "k"}], "]"}], "]"}]}], ";", 
               RowBox[{
                RowBox[{"H", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "iii"}], "]"}], "]"}], "=", 
                RowBox[{
                 RowBox[{"-", "\[ImaginaryI]"}], " ", 
                 RowBox[{"Power", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], ",", 
                   RowBox[{"Mod", "[", 
                    RowBox[{
                    RowBox[{"j", "-", "k"}], ",", "3"}], "]"}]}], "]"}], 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"S", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "==", "1"}], ",", "i", 
                    ",", "ii"}], "]"}], ",", "j"}], "]"}], "]"}], 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"S", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "==", "1"}], ",", "iii", 
                    ",", "ii"}], "]"}], ",", "k"}], "]"}], "]"}], "K"}]}]}]}],
              "]"}]}], "]"}]}]}], "]"}]}], "]"}], ";", 
     RowBox[{"H", "=", 
      RowBox[{"H", "+", 
       RowBox[{"ConjugateTranspose", "[", "H", "]"}]}]}], ";", 
     RowBox[{"S0", "=", 
      RowBox[{"Eigensystem", "[", "H", "]"}]}], ";", 
     RowBox[{"E0", "=", 
      RowBox[{"S0", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", 
     RowBox[{"V0", "=", 
      RowBox[{"S0", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", 
     RowBox[{"P0", "=", 
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"Sign", "[", "E0", "]"}], ",", "1"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";", 
     RowBox[{"E0", "=", 
      RowBox[{"E0", "[", 
       RowBox[{"[", "P0", "]"}], "]"}]}], ";", 
     RowBox[{"V0", "=", 
      RowBox[{"V0", "[", 
       RowBox[{"[", "P0", "]"}], "]"}]}], ";", 
     RowBox[{"{", 
      RowBox[{"E0", ",", "V0"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.929194693439515*^9, 3.929194788438962*^9}, {
  3.9291948211812725`*^9, 3.929194860547057*^9}, {3.9291949278593683`*^9, 
  3.92919496185135*^9}, {3.9291950255707874`*^9, 3.9291950360682898`*^9}, {
  3.929195078042835*^9, 3.9291951549309874`*^9}, {3.929195742249631*^9, 
  3.9291957439835653`*^9}, {3.930059062877959*^9, 3.9300590871535683`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"fe7774af-5a43-43f3-bae3-e0114204cc42"],

Cell["\<\
Function for plotting the fermion density of states against energy; \
\[OpenCurlyDoubleQuote]E0\[CloseCurlyDoubleQuote] is the list of energy \
eigenvalues and \[OpenCurlyDoubleQuote]d\[CloseCurlyDoubleQuote] is the step \
size (i.e., resolution) in energy.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, 
   3.9296339315330005`*^9},ExpressionUUID->"1ad187d4-4b8f-4377-bf7f-\
8dc0c172e5f5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotDOS", "[", 
   RowBox[{"E0_", ",", "d_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", "l", ",", "DOS", ",", "i"}], "}"}], ",", 
    RowBox[{
     RowBox[{"m", "=", 
      RowBox[{"Length", "[", "E0", "]"}]}], ";", 
     RowBox[{"l", "=", 
      RowBox[{
       RowBox[{"Ceiling", "[", 
        RowBox[{"Max", "[", 
         RowBox[{"E0", "/", "d"}], "]"}], "]"}], "+", "1"}]}], ";", 
     RowBox[{"DOS", "=", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", "l"}], "]"}]}], ";", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "<=", "m"}], ",", 
       RowBox[{"i", "++"}], ",", 
       RowBox[{
        RowBox[{"DOS", "[", 
         RowBox[{"[", 
          RowBox[{"Ceiling", "[", 
           RowBox[{
            RowBox[{"E0", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "/", "d"}], "]"}], "]"}], "]"}], 
        "++"}]}], "]"}], ";", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"h", "-", "0.5"}], ")"}], "d"}], ",", 
            RowBox[{"{", 
             RowBox[{"h", ",", "1", ",", "l"}], "}"}]}], "]"}], ",", "DOS"}], 
         "}"}], "]"}], ",", 
       RowBox[{"Joined", "->", "True"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.929197794097102*^9, 3.9291980199347754`*^9}, {
  3.92919807028218*^9, 3.929198178763279*^9}, {3.92919896801036*^9, 
  3.929199015905221*^9}, {3.9292000083595896`*^9, 3.9292000464287777`*^9}, {
  3.9295468656044707`*^9, 3.9295468658042793`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"7f9617a6-9f05-4145-a74f-dff6e660a68f"],

Cell["\<\
Function for plotting the real-space wave function of a given fermion \
eigenmode on the honeycomb lattice; \[OpenCurlyDoubleQuote]L\
\[CloseCurlyDoubleQuote] is the \[OpenCurlyDoubleQuote]Lattice\
\[CloseCurlyDoubleQuote] object created by the first function above, \
\[OpenCurlyDoubleQuote]U\[CloseCurlyDoubleQuote] is an \
\[OpenCurlyDoubleQuote]m\[CloseCurlyDoubleQuote] x 3 matrix of the gauge \
fields around the \[OpenCurlyDoubleQuote]m\[CloseCurlyDoubleQuote] sites on \
sublattice A (with the 3 elements in each row corresponding to x=1, y=2, and \
z=3 bonds, respectively), \[OpenCurlyDoubleQuote]V0\[CloseCurlyDoubleQuote] \
is the real-space wave function (i.e., eigenvector), while \
\[OpenCurlyDoubleQuote]p\[CloseCurlyDoubleQuote] is the picture size and \
\[OpenCurlyDoubleQuote]f\[CloseCurlyDoubleQuote] is the font size for site \
labels (there are no site labels if \[OpenCurlyDoubleQuote]f\
\[CloseCurlyDoubleQuote] is set to zero); the area of the disk around each \
site is proportional to the absolute value of the fermion wave function at \
the given site, while the color of the disk is indicative of the \
corresponding complex phase modulo \[Pi].\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.9292027029783583`*^9, 
   3.9292027244576616`*^9}, {3.9292029827876253`*^9, 3.929203080545811*^9}, {
   3.9295478523639092`*^9, 3.929547949201003*^9}, {3.9296326677770567`*^9, 
   3.929632669924919*^9}, 3.929633936438053*^9, {3.930059185677022*^9, 
   3.9300592210721607`*^9}, {3.9300613131193666`*^9, 
   3.9300613149938693`*^9}, {3.9300636542891083`*^9, 
   3.93006366472414*^9}},ExpressionUUID->"8454923f-b0d7-4328-83bc-\
e9f877c0ea8d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotMode", "[", 
   RowBox[{"L_", ",", "U_", ",", "V0_", ",", "p_", ",", "f_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "m", ",", "S", ",", "P", ",", "PP", ",", "B", ",", "n", ",", "a", ",", 
      "b"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", "S", ",", "P", ",", "PP", ",", "B"}], "}"}], "=", 
      "L"}], ";", 
     RowBox[{"n", "=", 
      RowBox[{"2", "m"}]}], ";", 
     RowBox[{"a", "=", "0.3"}], ";", 
     RowBox[{"b", "=", "0.2"}], ";", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Hue", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Arg", "[", 
                 RowBox[{"V0", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "]"}], "/", "\[Pi]"}], ",", 
               "0.5", ",", "1"}], "]"}], ",", 
             RowBox[{"Disk", "[", 
              RowBox[{
               RowBox[{"P", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", 
               RowBox[{"Sqrt", "[", 
                RowBox[{"b", " ", 
                 RowBox[{
                  RowBox[{"Abs", "[", 
                   RowBox[{"V0", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], "/", 
                  RowBox[{"Max", "[", 
                   RowBox[{"Abs", "[", "V0", "]"}], "]"}]}]}], "]"}]}], 
              "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"U", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"S", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "==", "1"}], ",", "i", 
                    ",", 
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "]"}], ",", 
                   "j"}], "]"}], "]"}], "!=", "0"}], ",", 
               RowBox[{"{", 
                RowBox[{"Black", ",", 
                 RowBox[{"Thickness", "[", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"U", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"S", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "==", "1"}], ",", "i", 
                    ",", 
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "]"}], ",", 
                    "j"}], "]"}], "]"}], ">", "0"}], ",", "0.0005", ",", 
                    "0.005"}], "]"}], "]"}], ",", 
                 RowBox[{"Line", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"P", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"PP", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}], "]"}]}], 
                "}"}]}], "]"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Length", "[", 
                 RowBox[{"Position", "[", 
                  RowBox[{"P", ",", 
                   RowBox[{"PP", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "]"}], "]"}], "==",
                 "0"}], ",", 
               RowBox[{"{", 
                RowBox[{"Blue", ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{
                   RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
                    RowBox[{"PP", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "]"}], ",", 
                   RowBox[{"Background", "->", "White"}]}], "]"}]}], "}"}]}], 
              "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"S", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "==", "1"}], ",", "Black", 
               ",", "Red"}], "]"}], ",", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{"i", ",", 
                 RowBox[{"P", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
               RowBox[{"Background", "->", "White"}]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "1"}], "]"}], "]"}], 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", "3"}], "]"}], 
                    "]"}], ",", "3"}], "]"}], "]"}], 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", "3"}], "]"}], 
                    "]"}], ",", "2"}], "]"}], "]"}], 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", "3"}], "]"}], 
                    "]"}], ",", "1"}], "]"}], "]"}], 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"B", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", "3"}], "]"}], 
                    "]"}], ",", "3"}], "]"}], "]"}], 
                 RowBox[{"U", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "<", "0"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Line", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"P", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "-", 
                    RowBox[{"r", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "+", 
                    RowBox[{"a", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "1"}], "}"}]}]}], ",", 
                    RowBox[{
                    RowBox[{"P", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "-", 
                    RowBox[{"r", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "+", 
                    RowBox[{"a", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}]}], "}"}]}]}]}], "}"}], "]"}], ",", 
                 RowBox[{"Line", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"P", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "-", 
                    RowBox[{"r", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "+", 
                    RowBox[{"a", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}], "}"}]}]}], ",", 
                    RowBox[{
                    RowBox[{"P", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "-", 
                    RowBox[{"r", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "+", 
                    RowBox[{"a", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}]}], "}"}], 
                  "]"}]}], "}"}]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "m"}], "}"}]}], "]"}]}], "}"}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", "Times"}], ",", 
          RowBox[{"FontSize", "\[Rule]", "f"}]}], "}"}]}], ",", 
       RowBox[{"ImageSize", "->", "p"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.929189051732794*^9, 3.929189098924832*^9}, {
   3.9291891373690634`*^9, 3.9291891602541895`*^9}, {3.929189305727453*^9, 
   3.9291893398913016`*^9}, {3.9291893889266543`*^9, 
   3.9291893982370024`*^9}, {3.9291900306423826`*^9, 
   3.9291900326619616`*^9}, {3.9291900957841988`*^9, 
   3.9291901074845724`*^9}, {3.929190467246254*^9, 3.929190485320138*^9}, {
   3.929190540354087*^9, 3.9291905709094057`*^9}, {3.9291906338633585`*^9, 
   3.929190783218895*^9}, {3.929190853186833*^9, 3.9291909217488556`*^9}, {
   3.929190963426565*^9, 3.9291909771889505`*^9}, {3.9291910088207283`*^9, 
   3.9291910610682573`*^9}, {3.929195403584087*^9, 3.9291954929068155`*^9}, {
   3.9291960547338886`*^9, 3.9291961424164076`*^9}, {3.929196177845583*^9, 
   3.929196180204406*^9}, {3.92919622281936*^9, 3.929196228864853*^9}, {
   3.9291962697458344`*^9, 3.9291962700895443`*^9}, {3.9291965526348305`*^9, 
   3.9291965638202596`*^9}, {3.9291966223846297`*^9, 3.9291966513153353`*^9}, 
   3.9291968621174316`*^9, 3.9291982300167103`*^9, {3.9291982903931847`*^9, 
   3.9291983304462347`*^9}, {3.9292012440567656`*^9, 3.929201273002345*^9}, 
   3.9292013511313086`*^9, {3.929201381664683*^9, 3.929201395585989*^9}, {
   3.9292014481611166`*^9, 3.9292014537012343`*^9}, {3.929548123777043*^9, 
   3.9295481685235825`*^9}, 3.929548378406285*^9, {3.9295500834854665`*^9, 
   3.9295500855869074`*^9}, {3.9300591196145473`*^9, 3.9300591606204844`*^9}, 
   3.9300598373488345`*^9, {3.9300604905636215`*^9, 3.930060491204133*^9}, {
   3.9300613202894063`*^9, 3.930061320586246*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"8bc47958-9619-4af9-89f0-75ea337bfd76"],

Cell["\<\
Function for computing the fermion energy as a function of momentum in the \
ground-state flux sector with all gauge fluxes being +1; \
\[OpenCurlyDoubleQuote]q\[CloseCurlyDoubleQuote] is the fermion momentum, \
while \[OpenCurlyDoubleQuote]J\[CloseCurlyDoubleQuote] contains the three \
Kitaev coupling strengths on x=1, y=2, and z=3 bonds, respectively, and \
\[OpenCurlyDoubleQuote]K\[CloseCurlyDoubleQuote] is the strength of the \
three-spin coupling that breaks time-reversal symmetry.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.9292027029783583`*^9, 
   3.9292027244576616`*^9}, {3.9292029827876253`*^9, 3.929203080545811*^9}, {
   3.9295478523639092`*^9, 3.929547949201003*^9}, {3.9296326677770567`*^9, 
   3.929632669924919*^9}, 3.929633936438053*^9, {3.930059185677022*^9, 
   3.9300592210721607`*^9}, {3.9300592790895343`*^9, 
   3.9300593131129026`*^9}, {3.9300593534007215`*^9, 3.930059402623465*^9}, {
   3.930059456345283*^9, 3.930059461531416*^9}, {3.9300595138003125`*^9, 
   3.9300595623670983`*^9}, {3.930059656407226*^9, 3.930059719017565*^9}, {
   3.930059926523088*^9, 3.9300599319124365`*^9}, {3.930070545744212*^9, 
   3.9300705487927055`*^9}},ExpressionUUID->"c11d83f8-c70a-4fc0-a8eb-\
2cba7da19751"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FermionDispersion", "[", 
   RowBox[{"q_", ",", "J_", ",", "K_"}], "]"}], ":=", 
  RowBox[{"2", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"Power", "[", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"J", "[", 
            RowBox[{"[", "h", "]"}], "]"}], 
           RowBox[{"Exp", "[", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"q", ".", 
              RowBox[{"r", "[", 
               RowBox[{"[", "h", "]"}], "]"}]}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"h", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
       "2"}], "]"}], "+", 
     RowBox[{"Power", "[", 
      RowBox[{
       RowBox[{"2", "K", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"q", ".", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"r", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "-", 
              RowBox[{"r", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "]"}], "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"q", ".", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"r", "[", 
               RowBox[{"[", "3", "]"}], "]"}], "-", 
              RowBox[{"r", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], "]"}], "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"q", ".", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"r", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "-", 
              RowBox[{"r", "[", 
               RowBox[{"[", "3", "]"}], "]"}]}], ")"}]}], "]"}]}], ")"}]}], 
       ",", "2"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.929189051732794*^9, 3.929189098924832*^9}, {
   3.9291891373690634`*^9, 3.9291891602541895`*^9}, {3.929189305727453*^9, 
   3.9291893398913016`*^9}, {3.9291893889266543`*^9, 
   3.9291893982370024`*^9}, {3.9291900306423826`*^9, 
   3.9291900326619616`*^9}, {3.9291900957841988`*^9, 
   3.9291901074845724`*^9}, {3.929190467246254*^9, 3.929190485320138*^9}, {
   3.929190540354087*^9, 3.9291905709094057`*^9}, {3.9291906338633585`*^9, 
   3.929190783218895*^9}, {3.929190853186833*^9, 3.9291909217488556`*^9}, {
   3.929190963426565*^9, 3.9291909771889505`*^9}, {3.9291910088207283`*^9, 
   3.9291910610682573`*^9}, {3.929195403584087*^9, 3.9291954929068155`*^9}, {
   3.9291960547338886`*^9, 3.9291961424164076`*^9}, {3.929196177845583*^9, 
   3.929196180204406*^9}, {3.92919622281936*^9, 3.929196228864853*^9}, {
   3.9291962697458344`*^9, 3.9291962700895443`*^9}, {3.9291965526348305`*^9, 
   3.9291965638202596`*^9}, {3.9291966223846297`*^9, 3.9291966513153353`*^9}, 
   3.9291968621174316`*^9, 3.9291982300167103`*^9, {3.9291982903931847`*^9, 
   3.9291983304462347`*^9}, {3.9292012440567656`*^9, 3.929201273002345*^9}, 
   3.9292013511313086`*^9, {3.929201381664683*^9, 3.929201395585989*^9}, {
   3.9292014481611166`*^9, 3.9292014537012343`*^9}, {3.929548123777043*^9, 
   3.9295481685235825`*^9}, 3.929548378406285*^9, {3.9295500834854665`*^9, 
   3.9295500855869074`*^9}, {3.9300591196145473`*^9, 
   3.9300591606204844`*^9}, {3.9300594134802732`*^9, 3.930059425571165*^9}, {
   3.9300594776369815`*^9, 3.9300595003817396`*^9}, {3.9300595780977535`*^9, 
   3.930059647206418*^9}, {3.930060791133936*^9, 3.930060793586401*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"c2060233-8385-48ae-93c0-e3e3c2dfb4a1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definitions and initialization", "Section",
 CellChangeTimes->{{3.9292017673387065`*^9, 3.929201775727317*^9}, {
  3.929544109709558*^9, 
  3.929544169457388*^9}},ExpressionUUID->"c5e8bf5c-f625-4905-934f-\
25cce56d8230"],

Cell["Define lattice vectors of the honeycomb lattice.", "Text",
 CellChangeTimes->{{3.9292017983001833`*^9, 3.9292018231069536`*^9}, {
  3.929633940109171*^9, 
  3.9296339535278797`*^9}},ExpressionUUID->"02e222f6-38e0-4868-aaba-\
48cbda38c42f"],

Cell[BoxData[
 RowBox[{"R", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sqrt", "[", "3", "]"}]}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Sqrt", "[", "3", "]"}], ",", "3"}], "}"}]}], "}"}], "/", 
   "2"}]}]], "Input",
 CellChangeTimes->{{3.917527532076995*^9, 3.9175275924513273`*^9}, {
  3.9291864731824155`*^9, 3.9291864744791117`*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"1b8dee3f-3571-4627-90b2-16ea9b5b266f"],

Cell["Define reciprocal lattice vectors of the honeycomb lattice.", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
  3.9296339420462165`*^9, 
  3.9296339582767773`*^9}},ExpressionUUID->"1e2fd7b6-8754-4e1e-9e53-\
f83c188a2a95"],

Cell[BoxData[
 RowBox[{"G", "=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"Inverse", "[", "R", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9175277547258654`*^9, 3.917527785787834*^9}, {
  3.91752781987893*^9, 3.917527821284869*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"25d7c490-6e53-4549-b050-1e67f3510b08"],

Cell["\<\
Define bond vectors pointing from any site in sublattice A to the three \
neighboring sites in sublattice B.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201873532501*^9}, {
  3.929633943826951*^9, 
  3.92963396177596*^9}},ExpressionUUID->"9030d8df-d7c0-4890-9a1f-\
4e2fababf806"],

Cell[BoxData[
 RowBox[{"r", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sqrt", "[", "3", "]"}]}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Sqrt", "[", "3", "]"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "2"}], "}"}]}], "}"}], "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.917527602232422*^9, 3.9175276099819283`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"ff4ff557-c832-4166-a111-95b0e6d6682d"],

Cell["\<\
Create and plot a 32 x 32 honeycomb lattice with \[OpenCurlyDoubleQuote]m\
\[CloseCurlyDoubleQuote] unit cells and \[OpenCurlyDoubleQuote]n\
\[CloseCurlyDoubleQuote] sites.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929546170107792*^9, 
   3.929546171974595*^9}, 
   3.92963394754483*^9},ExpressionUUID->"8645ee1d-4aa8-4a20-9bbc-\
464f9894d3dc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nx", "=", "32"}], ";", 
  RowBox[{"ny", "=", "32"}], ";", 
  RowBox[{"m", "=", 
   RowBox[{"nx", " ", "ny"}]}], ";", 
  RowBox[{"n", "=", 
   RowBox[{"2", "m"}]}], ";", 
  RowBox[{"L", "=", 
   RowBox[{"CreateLattice", "[", 
    RowBox[{"nx", ",", "ny"}], "]"}]}], ";", 
  RowBox[{"PlotLattice", "[", 
   RowBox[{"L", ",", "1000", ",", "8"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.929189022895851*^9, 3.9291890335497146`*^9}, {
   3.92919521247071*^9, 3.92919522692243*^9}, {3.9291957873639975`*^9, 
   3.929195788707594*^9}, {3.9291959144856663`*^9, 3.9291959156885476`*^9}, {
   3.9291982407642193`*^9, 3.92919824231069*^9}, {3.929198578535758*^9, 
   3.929198580972826*^9}, 3.9292031888328285`*^9, {3.9292036107405853`*^9, 
   3.929203612318341*^9}, {3.929546166477006*^9, 3.9295461765830455`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"6f007746-4b19-44b8-9740-67726add5c63"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gapless phase", "Section",
 CellChangeTimes->{{3.9292017673387065`*^9, 3.929201775727317*^9}, {
  3.9292031024468737`*^9, 3.9292031148502398`*^9}, {3.929544033492036*^9, 
  3.929544038148594*^9}, {3.9295457746889133`*^9, 
  3.929545775391691*^9}},ExpressionUUID->"67f4337f-ea5d-4930-b07a-\
a3b6778e9729"],

Cell["\<\
All three Kitaev couplings are equal, and there is no three-spin coupling.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203326185233*^9, 
   3.929203376892082*^9}, 
   3.9296339679620094`*^9},ExpressionUUID->"a5f41ac8-f40f-463d-820b-\
bf2e074eed57"],

Cell[BoxData[
 RowBox[{
  RowBox[{"J", "=", 
   RowBox[{"{", 
    RowBox[{"1.0", ",", "1.0", ",", "1.0"}], "}"}]}], ";", 
  RowBox[{"K", "=", "0.0"}], ";"}]], "Input",
 CellChangeTimes->{3.9292033237170734`*^9},
 CellLabel->"In[12]:=",ExpressionUUID->"d5ed3b1e-193e-49f6-aebd-377de8d40286"],

Cell["\<\
Define the ground-state flux sector with all gauge fields being +1; plot the \
corresponding configuration of gauge fields and gauge fluxes.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.929203585371544*^9, 3.929203603351858*^9}, {
   3.9292036552613745`*^9, 3.929203685488689*^9}, {3.929203892118185*^9, 
   3.929203894477137*^9}, 3.929544203254033*^9, {3.9295448469660916`*^9, 
   3.9295448489468575`*^9}, 
   3.9296339711642447`*^9},ExpressionUUID->"e8c61cc1-574c-41f3-891e-\
f77590b92344"],

Cell[BoxData[
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "3"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"PlotGauge", "[", 
   RowBox[{"L", ",", "U", ",", "600", ",", "0"}], "]"}]}]], "Input",
 CellChangeTimes->{3.929544216200843*^9, 3.9295444861218805`*^9},
 CellLabel->"In[13]:=",ExpressionUUID->"9c1d65f0-b810-4261-b0fa-bd4d7eca7952"],

Cell["\<\
Compute the fermion eigenmodes in the ground-state flux sector; plot their \
energies against mode label; notice the absence of a finite energy gap.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.9292038103249035`*^9, 3.929203811012282*^9}, 
   3.92920392822003*^9, {3.9295445556181602`*^9, 3.9295445635519485`*^9}, {
   3.929633983317641*^9, 3.929634008061865*^9}, {3.9296343065667953`*^9, 
   3.929634308987974*^9}},ExpressionUUID->"7deb112d-d4c7-48b4-b5c0-\
7943578cefe6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"E0", ",", "V0"}], "}"}], "=", 
   RowBox[{"FermionModes", "[", 
    RowBox[{"L", ",", "U", ",", "J", ",", "K"}], "]"}]}], ";", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"E0", ",", 
    RowBox[{"Joined", "->", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9291908069634123`*^9, 3.929190811524746*^9}, {
   3.929194505573979*^9, 3.9291945183367105`*^9}, 3.9291952372637477`*^9, {
   3.9291955602816143`*^9, 3.9291955980433397`*^9}, {3.929195697706516*^9, 
   3.929195698800005*^9}, {3.929195942088438*^9, 3.929195953882651*^9}, 
   3.9291963025507836`*^9, {3.9291966927285786`*^9, 3.9291967204408207`*^9}, {
   3.9291971847580357`*^9, 3.929197185601627*^9}, {3.9291975922778583`*^9, 
   3.929197623879712*^9}, {3.929197656075396*^9, 3.9291977258631*^9}, {
   3.929198459688538*^9, 3.9291984632659216`*^9}, {3.929198693591689*^9, 
   3.929198696950432*^9}, 3.9291987638251896`*^9, {3.929198863956543*^9, 
   3.9291988664403753`*^9}, 3.929200101743868*^9, 3.9292011029303656`*^9, 
   3.9292011489218097`*^9, 3.9292032903030343`*^9, {3.929203418366557*^9, 
   3.9292034368154907`*^9}, {3.929203474306675*^9, 3.9292034808363905`*^9}, 
   3.929544215229912*^9, {3.9300599547351685`*^9, 3.930059955078703*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"58da5985-346e-4d1f-8d0e-4de0c8663925"],

Cell["\<\
Plot the fermion density of states against energy; notice linear behavior at \
low energy, constant behavior at high energy, and a pronounced peak (Van Hove \
singularity) in between.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
   3.929203816542325*^9, 3.929203817479592*^9}, 3.9296340401637096`*^9, {
   3.9296340960569425`*^9, 
   3.9296341502473416`*^9}},ExpressionUUID->"2edc35fa-ac45-4ba6-9787-\
9d1cb6408101"],

Cell[BoxData[
 RowBox[{"PlotDOS", "[", 
  RowBox[{"E0", ",", "0.2"}], "]"}]], "Input",
 CellChangeTimes->{{3.9292035467583113`*^9, 3.929203556865403*^9}, {
  3.929544796665556*^9, 3.9295448026065288`*^9}, {3.9295462593283267`*^9, 
  3.9295462594754443`*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"4edbcad3-0509-4ca6-83a3-4ea983c546b4"],

Cell["\<\
Plot the real-space wave function of the highest-energy fermion eigenmode; \
notice that the wave function is delocalized over the entire lattice.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.9292038103249035`*^9, 3.929203811012282*^9}, 
   3.92920392822003*^9, {3.9295445556181602`*^9, 3.9295445635519485`*^9}, {
   3.9295482445059586`*^9, 3.9295482678533382`*^9}, {3.92954830694427*^9, 
   3.92954830897657*^9}, 3.9296340390857997`*^9, {3.929634163665927*^9, 
   3.929634178068938*^9}},ExpressionUUID->"ab341fcc-4fac-4f81-b449-\
63bc76131aa8"],

Cell[BoxData[
 RowBox[{"PlotMode", "[", 
  RowBox[{"L", ",", "U", ",", 
   RowBox[{"V0", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", "600", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.929548272412769*^9, 3.9295482881272335`*^9}, {
  3.9300599806976814`*^9, 3.930059981510026*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"e7fe2c05-2e65-49e2-90aa-5bbb1b5d3c8d"],

Cell["\<\
Plot the real-space wave function of the lowest-energy fermion eigenmode; \
notice that the wave function is delocalized over the entire lattice.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.9292038103249035`*^9, 3.929203811012282*^9}, 
   3.92920392822003*^9, {3.9295445556181602`*^9, 3.9295445635519485`*^9}, {
   3.9295482445059586`*^9, 3.9295482678533382`*^9}, {3.92954830694427*^9, 
   3.92954830897657*^9}, {3.9295484152004833`*^9, 3.9295484160009127`*^9}, {
   3.929548455890264*^9, 3.9295484697484255`*^9}, 3.9296340375705256`*^9, {
   3.9296341833644695`*^9, 
   3.9296341841768785`*^9}},ExpressionUUID->"5cdbdbe4-cb1c-47ff-bc30-\
5aec49511bc2"],

Cell[BoxData[
 RowBox[{"PlotMode", "[", 
  RowBox[{"L", ",", "U", ",", 
   RowBox[{"V0", "[", 
    RowBox[{"[", "m", "]"}], "]"}], ",", "600", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.929548272412769*^9, 3.9295482881272335`*^9}, {
  3.9295484175657167`*^9, 3.9295484177503643`*^9}, {3.9300600041608486`*^9, 
  3.9300600045515165`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"90c8a756-55fe-419e-bd0b-6c75a55c295d"],

Cell["\<\
Compute and plot the energy dispersion of fermion eigenmodes in momentum \
space (cf. electrons in graphene).\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
  3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
  3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
  3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
  3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
  3.929203816542325*^9, 3.929203817479592*^9}, {3.929544946184854*^9, 
  3.9295450287531033`*^9}, {3.92954513755802*^9, 3.9295451772067904`*^9}, {
  3.9296340586749835`*^9, 3.9296340716407194`*^9}, {3.9300600752038293`*^9, 
  3.9300600767502837`*^9}},ExpressionUUID->"d66e5edd-5b77-475f-8596-\
5a9e64811814"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"e", "[", "q_", "]"}], "=", 
   RowBox[{"FermionDispersion", "[", 
    RowBox[{"q", ",", "J", ",", "K"}], "]"}]}], ";", 
  RowBox[{"ContourPlot", "[", 
   RowBox[{
    RowBox[{"e", "[", 
     RowBox[{"{", 
      RowBox[{"qx", ",", "qy"}], "}"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"qx", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"qy", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9300600897471495`*^9, 3.930060110898509*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"6c3c4a3c-2e07-488a-8b9f-e8d8ba474f2f"],

Cell["\<\
Reproduce the fermion density of states by randomly sampling the fermion \
energies in momentum space.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
   3.929203816542325*^9, 3.929203817479592*^9}, {3.929544946184854*^9, 
   3.9295450287531033`*^9}, 
   3.929634075889797*^9},ExpressionUUID->"1907e137-7028-4448-b15d-\
77d0cc7fbd5c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"e", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["10", "6"], 
         RowBox[{"Random", "[", "]"}]}], ",", 
        RowBox[{
         SuperscriptBox["10", "6"], 
         RowBox[{"Random", "[", "]"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"h", ",", "1", ",", 
       SuperscriptBox["10", "6"]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"PlotDOS", "[", 
   RowBox[{"EE", ",", "0.05"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9295451892706995`*^9, 3.9295453314462967`*^9}, {
  3.9295465350409403`*^9, 3.929546535407956*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"78e121e0-e141-489d-add6-59eea3f8c2b3"],

Cell["\<\
Compute the energy of the fermion ground state in the ground-state flux \
sector (i.e., the overall ground-state energy).\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
   3.929203764326089*^9, 3.929203865718254*^9}, 
   3.929634197704956*^9},ExpressionUUID->"fff8175d-d132-417a-89bf-\
b1cbabce2006"],

Cell[BoxData[
 RowBox[{"GS0", "=", 
  RowBox[{
   RowBox[{"-", "0.5"}], 
   RowBox[{"Total", "[", "E0", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.9292037727302637`*^9, 3.9292037770260906`*^9}, {
  3.9292039144576435`*^9, 3.929203915988674*^9}, {3.9300601631049185`*^9, 
  3.9300601637922564`*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"717024fb-5c07-4945-a7ac-b038c78dd0f4"],

Cell["\<\
Introduce a pair of flux excitations by flipping a gauge field from +1 to -1; \
plot the resulting configuration of gauge fields and gauge fluxes.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.929203585371544*^9, 3.929203603351858*^9}, {
   3.9292036552613745`*^9, 3.929203685488689*^9}, {3.929203892118185*^9, 
   3.929203894477137*^9}, 
   3.9296342024537125`*^9},ExpressionUUID->"1ea3fb47-5921-40a9-aa87-\
2d6945f474d6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{"[", 
     RowBox[{"709", ",", "2"}], "]"}], "]"}], "=", 
   RowBox[{"-", "1"}]}], ";", 
  RowBox[{"PlotGauge", "[", 
   RowBox[{"L", ",", "U", ",", "600", ",", "0"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9292037006413407`*^9, 3.9292037253721395`*^9}, {
  3.929544819149984*^9, 3.92954481949667*^9}, {3.9295463245748944`*^9, 
  3.9295463250443497`*^9}, {3.9295470112171464`*^9, 3.9295470186242433`*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"c5e640a5-9e06-47db-8b25-2f5d6d129ce2"],

Cell["\<\
Compute the energy of the fermion ground state in the excited flux sector \
with a pair of flux excitations.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
   3.929203764326089*^9, 3.9292039045382557`*^9}, 
   3.929634218699883*^9},ExpressionUUID->"8739d6e1-bae3-4ec1-a981-\
e295c87b6e5d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"E0", ",", "V0"}], "}"}], "=", 
   RowBox[{"FermionModes", "[", 
    RowBox[{"L", ",", "U", ",", "J", ",", "K"}], "]"}]}], ";", 
  RowBox[{"GS2", "=", 
   RowBox[{
    RowBox[{"-", "0.5"}], 
    RowBox[{"Total", "[", "E0", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.929203966392908*^9, 3.9292039665489883`*^9}, 
   3.9292040170371227`*^9, {3.9300601760548754`*^9, 3.9300601795998683`*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"fbb42755-7046-4a98-a646-187a4ecd61e3"],

Cell["Compute the excitation energy of a flux pair.", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
   3.929203764326089*^9, 3.9292039045382557`*^9}, {3.9292039755937357`*^9, 
   3.9292039814674973`*^9}, 
   3.929634220699417*^9},ExpressionUUID->"0bbca73a-7843-432c-b3b3-\
1305554bc1b5"],

Cell[BoxData[
 RowBox[{"GS2", "-", "GS0"}]], "Input",
 CellChangeTimes->{{3.9292039838886976`*^9, 3.929203985669635*^9}, {
  3.9300602148102703`*^9, 3.930060218450035*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"d070635d-f54f-45f9-85cb-84d8fb195ed7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Anisotropic gapped (Abelian) phase", "Section",
 CellChangeTimes->{{3.9292017673387065`*^9, 3.929201775727317*^9}, {
  3.9292031024468737`*^9, 3.9292031148502398`*^9}, {3.9292042382314434`*^9, 
  3.929204277826107*^9}, {3.929545748835946*^9, 
  3.9295457688709364`*^9}},ExpressionUUID->"83acea49-2575-45a9-b451-\
ed74c79894c7"],

Cell["\<\
One Kitaev coupling dominates, and there is still no three-spin coupling.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203326185233*^9, 
   3.929203376892082*^9}, {3.9292042996052685`*^9, 3.9292043597786255`*^9}, {
   3.929545845879922*^9, 3.9295458471887836`*^9}, 
   3.929634242303858*^9},ExpressionUUID->"60dfdbd1-23c5-410f-9d0f-\
c8db2644f8ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"J", "=", 
   RowBox[{"{", 
    RowBox[{"0.2", ",", "0.2", ",", "1.0"}], "}"}]}], ";", 
  RowBox[{"K", "=", "0.0"}], ";"}]], "Input",
 CellChangeTimes->{
  3.9292033237170734`*^9, {3.92920433436272*^9, 3.9292043622935667`*^9}, {
   3.929204413344033*^9, 3.929204415062377*^9}, {3.9292045522186203`*^9, 
   3.9292045530778117`*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"eca4f02b-b24f-451d-a567-c0069ba2ae45"],

Cell["\<\
Define the ground-state flux sector with all gauge fields being +1; compute \
the fermion eigenmodes; plot their energies against mode label; notice the \
presence of a finite energy gap.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.9292038103249035`*^9, 3.929203811012282*^9}, 
   3.92920392822003*^9, 3.929634245959152*^9, {3.929634283368984*^9, 
   3.9296342999277334`*^9}},ExpressionUUID->"f2d2f08c-eb15-483e-93aa-\
2bc0d7c85033"],

Cell[BoxData[
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "3"}], "}"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"E0", ",", "V0"}], "}"}], "=", 
   RowBox[{"FermionModes", "[", 
    RowBox[{"L", ",", "U", ",", "J", ",", "K"}], "]"}]}], ";", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"E0", ",", 
    RowBox[{"Joined", "->", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9291908069634123`*^9, 3.929190811524746*^9}, {
   3.929194505573979*^9, 3.9291945183367105`*^9}, 3.9291952372637477`*^9, {
   3.9291955602816143`*^9, 3.9291955980433397`*^9}, {3.929195697706516*^9, 
   3.929195698800005*^9}, {3.929195942088438*^9, 3.929195953882651*^9}, 
   3.9291963025507836`*^9, {3.9291966927285786`*^9, 3.9291967204408207`*^9}, {
   3.9291971847580357`*^9, 3.929197185601627*^9}, {3.9291975922778583`*^9, 
   3.929197623879712*^9}, {3.929197656075396*^9, 3.9291977258631*^9}, {
   3.929198459688538*^9, 3.9291984632659216`*^9}, {3.929198693591689*^9, 
   3.929198696950432*^9}, 3.9291987638251896`*^9, {3.929198863956543*^9, 
   3.9291988664403753`*^9}, 3.929200101743868*^9, 3.9292011029303656`*^9, 
   3.9292011489218097`*^9, 3.9292032903030343`*^9, {3.929203418366557*^9, 
   3.9292034368154907`*^9}, {3.929203474306675*^9, 3.9292034808363905`*^9}, {
   3.9300602374823675`*^9, 3.930060237779174*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"05b2b67d-e61b-4e99-a980-73bf8de8b83d"],

Cell["\<\
Plot the fermion density of states against energy; notice the reduction of \
the fermion band width with respect to the gapless phase.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
  3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
  3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
  3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
  3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
  3.929203816542325*^9, 3.929203817479592*^9}, {3.929634334997611*^9, 
  3.929634378253004*^9}},ExpressionUUID->"068c4c9e-4326-4a3a-8139-\
3f935e739352"],

Cell[BoxData[
 RowBox[{"PlotDOS", "[", 
  RowBox[{"E0", ",", "0.2"}], "]"}]], "Input",
 CellChangeTimes->{{3.9292035467583113`*^9, 3.929203556865403*^9}, {
  3.9292045899596157`*^9, 3.929204592349674*^9}, {3.9295466155307407`*^9, 
  3.929546615699669*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"72262ae5-9953-4eab-a0eb-1507867ee799"],

Cell["\<\
Plot the real-space wave function of the highest-energy fermion eigenmode; \
notice that the wave function is delocalized over the entire lattice.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.9292038103249035`*^9, 3.929203811012282*^9}, 
   3.92920392822003*^9, {3.9295445556181602`*^9, 3.9295445635519485`*^9}, {
   3.9295482445059586`*^9, 3.9295482678533382`*^9}, {3.92954830694427*^9, 
   3.92954830897657*^9}, {3.929634398467105*^9, 
   3.929634399185683*^9}},ExpressionUUID->"258e755b-918c-4bde-aed5-\
da5e4b62aea8"],

Cell[BoxData[
 RowBox[{"PlotMode", "[", 
  RowBox[{"L", ",", "U", ",", 
   RowBox[{"V0", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", "600", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.929548272412769*^9, 3.9295482881272335`*^9}, {
  3.9300602675221167`*^9, 3.930060267787711*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"3ffed24b-9eaa-4211-9c40-8b3a9bafdcce"],

Cell["\<\
Plot the real-space wave function of the lowest-energy fermion eigenmode; \
notice that the wave function is delocalized over the entire lattice.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.9292038103249035`*^9, 3.929203811012282*^9}, 
   3.92920392822003*^9, {3.9295445556181602`*^9, 3.9295445635519485`*^9}, {
   3.9295482445059586`*^9, 3.9295482678533382`*^9}, {3.92954830694427*^9, 
   3.92954830897657*^9}, {3.9295484152004833`*^9, 3.9295484160009127`*^9}, {
   3.929548455890264*^9, 3.9295484697484255`*^9}, {3.9296344017106547`*^9, 
   3.929634402210672*^9}},ExpressionUUID->"a7e62060-3d89-4da1-a703-\
7cb2b123ce85"],

Cell[BoxData[
 RowBox[{"PlotMode", "[", 
  RowBox[{"L", ",", "U", ",", 
   RowBox[{"V0", "[", 
    RowBox[{"[", "m", "]"}], "]"}], ",", "600", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.929548272412769*^9, 3.9295482881272335`*^9}, {
  3.9295484175657167`*^9, 3.9295484177503643`*^9}, {3.930060271427363*^9, 
  3.9300602716929255`*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"4124ffb2-c6cd-4a84-8b39-35d678ca7a5b"],

Cell["\<\
Compute and plot the energy dispersion of fermion eigenmodes in momentum \
space.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
   3.929203816542325*^9, 3.929203817479592*^9}, {3.929544946184854*^9, 
   3.9295450287531033`*^9}, {3.92954513755802*^9, 3.9295451772067904`*^9}, {
   3.9296340586749835`*^9, 3.9296340716407194`*^9}, {3.9300600752038293`*^9, 
   3.9300600767502837`*^9}, 
   3.930060331471184*^9},ExpressionUUID->"4a75a4ab-bf1d-4cd2-ab1e-\
aeafb7b3741a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"e", "[", "q_", "]"}], "=", 
   RowBox[{"FermionDispersion", "[", 
    RowBox[{"q", ",", "J", ",", "K"}], "]"}]}], ";", 
  RowBox[{"ContourPlot", "[", 
   RowBox[{
    RowBox[{"e", "[", 
     RowBox[{"{", 
      RowBox[{"qx", ",", "qy"}], "}"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"qx", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"qy", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9300600897471495`*^9, 3.930060110898509*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"9ee27879-655c-468f-92ad-a92f2d3f8731"],

Cell["\<\
Reproduce the fermion density of states by randomly sampling the fermion \
energies in momentum space.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
   3.929203816542325*^9, 3.929203817479592*^9}, {3.929544946184854*^9, 
   3.9295450287531033`*^9}, 
   3.929634075889797*^9},ExpressionUUID->"956e20a7-448f-49d0-a240-\
9605412b667d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"e", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["10", "6"], 
         RowBox[{"Random", "[", "]"}]}], ",", 
        RowBox[{
         SuperscriptBox["10", "6"], 
         RowBox[{"Random", "[", "]"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"h", ",", "1", ",", 
       SuperscriptBox["10", "6"]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"PlotDOS", "[", 
   RowBox[{"EE", ",", "0.05"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9295451892706995`*^9, 3.9295453314462967`*^9}, {
  3.9295465350409403`*^9, 3.929546535407956*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"9f405d0f-7f35-4de0-9e4f-0509e7a80466"],

Cell["\<\
Compute the energy of the fermion ground state in the ground-state flux \
sector (i.e., the overall ground-state energy).\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
   3.929203764326089*^9, 3.929203865718254*^9}, 
   3.929634197704956*^9},ExpressionUUID->"4e16470f-e238-4df0-89e5-\
25cee4d8a8c1"],

Cell[BoxData[
 RowBox[{"GS0", "=", 
  RowBox[{
   RowBox[{"-", "0.5"}], 
   RowBox[{"Total", "[", "E0", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.9292037727302637`*^9, 3.9292037770260906`*^9}, {
  3.9292039144576435`*^9, 3.929203915988674*^9}, {3.9300603677594833`*^9, 
  3.930060368040803*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"9de123b6-b2c0-447d-a9dc-8bf98172daf2"],

Cell["\<\
Introduce a pair of flux excitations by flipping a gauge field from +1 to -1; \
compute the energy of the fermion ground state in the excited flux sector \
with a pair of flux excitations.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.929203585371544*^9, 3.929203603351858*^9}, {
   3.9292036552613745`*^9, 3.929203685488689*^9}, {3.929203892118185*^9, 
   3.929203894477137*^9}, {3.9295469946915684`*^9, 3.929546996124751*^9}, 
   3.929634479083252*^9},ExpressionUUID->"fbd8315c-2420-440f-9a66-\
addbe17ae1a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{"[", 
     RowBox[{"709", ",", "2"}], "]"}], "]"}], "=", 
   RowBox[{"-", "1"}]}], ";", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"E0", ",", "V0"}], "}"}], "=", 
   RowBox[{"FermionModes", "[", 
    RowBox[{"L", ",", "U", ",", "J", ",", "K"}], "]"}]}], ";", 
  RowBox[{"GS2", "=", 
   RowBox[{
    RowBox[{"-", "0.5"}], 
    RowBox[{"Total", "[", "E0", "]"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.929547031703597*^9, {3.9300603736799583`*^9, 3.9300603774603186`*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"290765c1-1ce1-43e2-ad90-760e256693b1"],

Cell["\<\
Compute the excitation energy of a flux pair; notice that it is much smaller \
than in the gapless phase.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
  3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
  3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
  3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
  3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
  3.929203764326089*^9, 3.9292039045382557`*^9}, {3.9292039755937357`*^9, 
  3.9292039814674973`*^9}, {3.929634492345663*^9, 
  3.9296345045772734`*^9}},ExpressionUUID->"51a92af8-5026-41ed-a1a2-\
c6bf21b59503"],

Cell[BoxData[
 RowBox[{"GS2", "-", "GS0"}]], "Input",
 CellChangeTimes->{{3.9292039838886976`*^9, 3.929203985669635*^9}, {
  3.9300604001893187`*^9, 3.930060402657627*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"f781716b-7c9b-4163-a8b5-7f60d66113e5"],

Cell[TextData[StyleBox["Exercise 1: Explore how the excitation energy of a \
flux pair changes as the distance between the two fluxes is increased. Are \
the two fluxes confined to each other, or can they be separated to arbitrary \
distance? (See the simple examples below for how one can create, manipulate, \
and plot lists in Mathematica.)",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
  3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
  3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
  3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
  3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
  3.929203764326089*^9, 3.9292039045382557`*^9}, {3.9292039755937357`*^9, 
  3.9292039814674973`*^9}, {3.9295454772656755`*^9, 3.9295454957966723`*^9}, {
  3.9296328982035522`*^9, 3.9296329597516127`*^9}, {3.9296329936030006`*^9, 
  3.9296331543308907`*^9}, {3.9300630593160048`*^9, 3.9300631048052907`*^9}, {
  3.930063152024913*^9, 
  3.9300631553366594`*^9}},ExpressionUUID->"28e266ac-a8ff-41cd-9c49-\
adb580a29722"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"myList1", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<=", "10"}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{
     RowBox[{"j", "=", 
      RowBox[{"i", "^", "2"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"myList1", ",", "j"}], "]"}], ";"}]}], "\[IndentingNewLine]", 
   "]"}], ";"}], "\[IndentingNewLine]", "myList1"}], "Input",
 CellChangeTimes->{{3.930062910319976*^9, 3.9300629251133113`*^9}, {
  3.930062955231336*^9, 3.93006298414638*^9}, {3.9300632750506153`*^9, 
  3.93006329976339*^9}},ExpressionUUID->"dcc4ec0e-3e78-4edc-8751-\
d6dba2949780"],

Cell[BoxData[
 RowBox[{"myList2", "=", 
  RowBox[{"Log", "[", "myList1", "]"}]}]], "Input",
 CellChangeTimes->{{3.930062910319976*^9, 3.9300629251133113`*^9}, {
  3.930062955231336*^9, 3.9300630042978573`*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"55051e44-d3a7-46f5-8083-54c1a35944ad"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", "myList1", "]"}]], "Input",
 CellChangeTimes->{{3.9300630109211607`*^9, 3.930063015654555*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"5fb4a8ef-1b4c-4454-b97f-3ce32c2248d7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Isotropic gapped (non-Abelian) phase", "Section",
 CellChangeTimes->{{3.9292017673387065`*^9, 3.929201775727317*^9}, {
  3.9292031024468737`*^9, 3.9292031148502398`*^9}, {3.9292042382314434`*^9, 
  3.929204248728974*^9}, {3.9295476986608753`*^9, 
  3.929547708406804*^9}},ExpressionUUID->"2028b6f9-cd15-4a3e-96c7-\
8644e972c8b7"],

Cell["\<\
All three Kitaev couplings are equal, and there is a finite three-spin \
coupling.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203326185233*^9, 
   3.929203376892082*^9}, {3.9295488715401163`*^9, 3.929548873643139*^9}, 
   3.929634554424801*^9},ExpressionUUID->"ec91d0b8-69a0-42bf-9b22-\
36d98570921a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"J", "=", 
   RowBox[{"{", 
    RowBox[{"1.0", ",", "1.0", ",", "1.0"}], "}"}]}], ";", 
  RowBox[{"K", "=", "0.2"}], ";"}]], "Input",
 CellChangeTimes->{3.9292033237170734`*^9, 3.9295488757836576`*^9, 
  3.929549669236556*^9, 3.930060701358156*^9, 3.9300608959529037`*^9},
 CellLabel->"In[60]:=",ExpressionUUID->"c1bf65e4-4854-474a-93b0-0b5e6d81ed85"],

Cell["\<\
Define the ground-state flux sector with all gauge fields being +1; compute \
the fermion eigenmodes; plot their energies against mode label; notice the \
presence of a finite energy gap.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.9292038103249035`*^9, 3.929203811012282*^9}, 
   3.92920392822003*^9, 3.929634245959152*^9, {3.929634283368984*^9, 
   3.9296342999277334`*^9}},ExpressionUUID->"2b7098bc-4908-4ebf-bfe1-\
0045cea3efe1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "3"}], "}"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"E0", ",", "V0"}], "}"}], "=", 
   RowBox[{"FermionModes", "[", 
    RowBox[{"L", ",", "U", ",", "J", ",", "K"}], "]"}]}], ";", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"E0", ",", 
    RowBox[{"Joined", "->", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9291908069634123`*^9, 3.929190811524746*^9}, {
   3.929194505573979*^9, 3.9291945183367105`*^9}, 3.9291952372637477`*^9, {
   3.9291955602816143`*^9, 3.9291955980433397`*^9}, {3.929195697706516*^9, 
   3.929195698800005*^9}, {3.929195942088438*^9, 3.929195953882651*^9}, 
   3.9291963025507836`*^9, {3.9291966927285786`*^9, 3.9291967204408207`*^9}, {
   3.9291971847580357`*^9, 3.929197185601627*^9}, {3.9291975922778583`*^9, 
   3.929197623879712*^9}, {3.929197656075396*^9, 3.9291977258631*^9}, {
   3.929198459688538*^9, 3.9291984632659216`*^9}, {3.929198693591689*^9, 
   3.929198696950432*^9}, 3.9291987638251896`*^9, {3.929198863956543*^9, 
   3.9291988664403753`*^9}, 3.929200101743868*^9, 3.9292011029303656`*^9, 
   3.9292011489218097`*^9, 3.9292032903030343`*^9, {3.929203418366557*^9, 
   3.9292034368154907`*^9}, {3.929203474306675*^9, 3.9292034808363905`*^9}, {
   3.930060442454236*^9, 3.930060442813567*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"96cfac57-baec-40de-89e3-a1b494032c9a"],

Cell["Plot the fermion density of states against energy.", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
  3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
  3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
  3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
  3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
  3.929203816542325*^9, 3.929203817479592*^9}, {3.929634334997611*^9, 
  3.929634378253004*^9}, {3.9296346290480537`*^9, 
  3.929634639326883*^9}},ExpressionUUID->"112eee7f-6438-4398-b451-\
83f7dee18de7"],

Cell[BoxData[
 RowBox[{"PlotDOS", "[", 
  RowBox[{"E0", ",", "0.1"}], "]"}]], "Input",
 CellChangeTimes->{{3.9292035467583113`*^9, 3.929203556865403*^9}, {
  3.9292045899596157`*^9, 3.929204592349674*^9}, {3.9295466155307407`*^9, 
  3.929546615699669*^9}, {3.929549683498563*^9, 3.929549683630245*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"da8480f9-bddb-42e0-b315-3dcc67a2a671"],

Cell["\<\
Plot the real-space wave function of the highest-energy fermion eigenmode; \
notice that the wave function is delocalized over the entire lattice.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.9292038103249035`*^9, 3.929203811012282*^9}, 
   3.92920392822003*^9, {3.9295445556181602`*^9, 3.9295445635519485`*^9}, {
   3.9295482445059586`*^9, 3.9295482678533382`*^9}, {3.92954830694427*^9, 
   3.92954830897657*^9}, {3.9296346544170923`*^9, 
   3.9296346549794607`*^9}},ExpressionUUID->"26becea2-9894-4b74-8e62-\
d97cb8ab1fd1"],

Cell[BoxData[
 RowBox[{"PlotMode", "[", 
  RowBox[{"L", ",", "U", ",", 
   RowBox[{"V0", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", "600", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.929548272412769*^9, 3.9295482881272335`*^9}, {
  3.9300604693187857`*^9, 3.9300604700217447`*^9}},
 CellLabel->"In[63]:=",ExpressionUUID->"359f362a-eca7-4b47-9b83-19dd2c75aa09"],

Cell["\<\
Plot the real-space wave function of the lowest-energy fermion eigenmode; \
notice that the wave function is delocalized over the entire lattice.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.9292038103249035`*^9, 3.929203811012282*^9}, 
   3.92920392822003*^9, {3.9295445556181602`*^9, 3.9295445635519485`*^9}, {
   3.9295482445059586`*^9, 3.9295482678533382`*^9}, {3.92954830694427*^9, 
   3.92954830897657*^9}, {3.9295484152004833`*^9, 3.9295484160009127`*^9}, {
   3.929548455890264*^9, 3.9295484697484255`*^9}, {3.929634657619465*^9, 
   3.92963465818173*^9}},ExpressionUUID->"93ee3494-5506-4c73-93f0-\
5c24a382d38c"],

Cell[BoxData[
 RowBox[{"PlotMode", "[", 
  RowBox[{"L", ",", "U", ",", 
   RowBox[{"V0", "[", 
    RowBox[{"[", "m", "]"}], "]"}], ",", "600", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.929548272412769*^9, 3.9295482881272335`*^9}, {
  3.9295484175657167`*^9, 3.9295484177503643`*^9}, {3.930060516042137*^9, 
  3.930060516801406*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"66220f66-b82c-4283-a078-5964e57e458c"],

Cell["\<\
Compute and plot the energy dispersion of fermion eigenmodes in momentum \
space.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
   3.929203816542325*^9, 3.929203817479592*^9}, {3.929544946184854*^9, 
   3.9295450287531033`*^9}, {3.92954513755802*^9, 3.9295451772067904`*^9}, {
   3.9296340586749835`*^9, 3.9296340716407194`*^9}, {3.9300600752038293`*^9, 
   3.9300600767502837`*^9}, 
   3.930060331471184*^9},ExpressionUUID->"c95e7f0f-09a4-42de-bb21-\
5521bf3cdaf5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"e", "[", "q_", "]"}], "=", 
   RowBox[{"FermionDispersion", "[", 
    RowBox[{"q", ",", "J", ",", "K"}], "]"}]}], ";", 
  RowBox[{"ContourPlot", "[", 
   RowBox[{
    RowBox[{"e", "[", 
     RowBox[{"{", 
      RowBox[{"qx", ",", "qy"}], "}"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"qx", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"qy", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9300600897471495`*^9, 3.930060110898509*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"4ecd1453-b82b-4a3d-9529-0019af1f84e4"],

Cell["\<\
Reproduce the fermion density of states by randomly sampling the fermion \
energies in momentum space.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
   3.929203816542325*^9, 3.929203817479592*^9}, {3.929544946184854*^9, 
   3.9295450287531033`*^9}, 
   3.929634075889797*^9},ExpressionUUID->"731f4040-98d7-488a-83ae-\
9ba226c322da"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"e", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["10", "6"], 
         RowBox[{"Random", "[", "]"}]}], ",", 
        RowBox[{
         SuperscriptBox["10", "6"], 
         RowBox[{"Random", "[", "]"}]}]}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"h", ",", "1", ",", 
       SuperscriptBox["10", "6"]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"PlotDOS", "[", 
   RowBox[{"EE", ",", "0.05"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9295451892706995`*^9, 3.9295453314462967`*^9}, {
  3.9295465350409403`*^9, 3.929546535407956*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"a8e97d92-7884-4c91-9d3e-d799116463c7"],

Cell["\<\
Compute the energy of the fermion ground state in the ground-state flux \
sector (i.e., the overall ground-state energy).\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
   3.929203764326089*^9, 3.929203865718254*^9}, 
   3.929634197704956*^9},ExpressionUUID->"ddf84ed7-8ccd-4e68-890d-\
c35bcbf13672"],

Cell[BoxData[
 RowBox[{"GS0", "=", 
  RowBox[{
   RowBox[{"-", "0.5"}], 
   RowBox[{"Total", "[", "E0", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.9292037727302637`*^9, 3.9292037770260906`*^9}, {
  3.9292039144576435`*^9, 3.929203915988674*^9}, {3.930060536808586*^9, 
  3.9300605371053877`*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"eb93bde5-54a5-4f7d-b437-60604e9cb60d"],

Cell["\<\
Introduce a pair of flux excitations by flipping a gauge field from +1 to -1; \
compute the energy of the fermion ground state in the excited flux sector \
with a pair of flux excitations.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.929203585371544*^9, 3.929203603351858*^9}, {
   3.9292036552613745`*^9, 3.929203685488689*^9}, {3.929203892118185*^9, 
   3.929203894477137*^9}, {3.9295469946915684`*^9, 3.929546996124751*^9}, 
   3.929634479083252*^9},ExpressionUUID->"469269bd-4666-4d82-a408-\
0fa872cdb97e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{"[", 
     RowBox[{"709", ",", "2"}], "]"}], "]"}], "=", 
   RowBox[{"-", "1"}]}], ";", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"E0", ",", "V0"}], "}"}], "=", 
   RowBox[{"FermionModes", "[", 
    RowBox[{"L", ",", "U", ",", "J", ",", "K"}], "]"}]}], ";", 
  RowBox[{"GS2", "=", 
   RowBox[{
    RowBox[{"-", "0.5"}], 
    RowBox[{"Total", "[", "E0", "]"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.929547031703597*^9, {3.9300605424792204`*^9, 3.9300605456190977`*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"b5e38e0f-ec09-4f49-9056-0853dee5137f"],

Cell["\<\
Compute the excitation energy of a flux pair; notice that it has the same \
order of magnitude as in the gapless phase.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
  3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
  3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
  3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
  3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
  3.929203764326089*^9, 3.9292039045382557`*^9}, {3.9292039755937357`*^9, 
  3.9292039814674973`*^9}, {3.929634492345663*^9, 3.9296345045772734`*^9}, {
  3.9296349822197094`*^9, 3.9296349874372296`*^9}, {3.930060562474476*^9, 
  3.9300605728000355`*^9}},ExpressionUUID->"9dfa97ca-3b4c-40fd-95de-\
73f17181ff0e"],

Cell[BoxData[
 RowBox[{"GS2", "-", "GS0"}]], "Input",
 CellChangeTimes->{{3.9292039838886976`*^9, 3.929203985669635*^9}, {
  3.9300605530390806`*^9, 3.930060555538488*^9}},
 CellLabel->"In[69]:=",ExpressionUUID->"5dfde632-8a10-4c5d-bf82-ec9445c61e88"],

Cell[TextData[StyleBox["Exercise 2: Explore how the excitation energy of a \
flux pair changes as the distance between the two fluxes is increased. Is \
there any noticeable difference with respect to the anisotropic gapped phase?",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
   3.929203764326089*^9, 3.9292039045382557`*^9}, {3.9292039755937357`*^9, 
   3.9292039814674973`*^9}, {3.9295454772656755`*^9, 
   3.9295454957966723`*^9}, {3.9296328982035522`*^9, 
   3.9296329597516127`*^9}, {3.9296329936030006`*^9, 
   3.9296331543308907`*^9}, {3.9296350319424067`*^9, 3.9296350830085464`*^9}, 
   3.93006153873777*^9},ExpressionUUID->"d8ea0d5a-4b7e-4eff-ad01-\
0bfea570f789"],

Cell["\<\
Create a pair of flux excitations far away from each other; plot the \
resulting configuration of gauge fields and gauge fluxes.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.929203585371544*^9, 3.929203603351858*^9}, {
   3.9292036552613745`*^9, 3.929203685488689*^9}, {3.929203892118185*^9, 
   3.929203894477137*^9}, 3.9296342024537125`*^9, {3.9296352192838483`*^9, 
   3.9296352297813845`*^9}},ExpressionUUID->"3e2062a4-ffa9-4e9e-ac53-\
8d8256bac86c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "3"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<=", "15"}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{
     RowBox[{"U", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"708", "+", "i"}], ",", "2"}], "]"}], "]"}], "=", 
     RowBox[{"-", "1"}]}]}], "]"}], ";", 
  RowBox[{"PlotGauge", "[", 
   RowBox[{"L", ",", "U", ",", "600", ",", "0"}], "]"}]}]], "Input",
 CellLabel->"In[70]:=",ExpressionUUID->"f6395340-b23b-4510-8fd4-2ef62ab72a0e"],

Cell["\<\
Compute the fermion eigenmodes; plot their energies against mode label; \
notice that there is at least one low-energy eigenmode very close to zero \
energy.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.9292038103249035`*^9, 3.929203811012282*^9}, 
   3.92920392822003*^9, {3.9295492555555134`*^9, 3.9295492838925824`*^9}, {
   3.9296353242188115`*^9, 3.9296353884068623`*^9}, {3.9296357435213437`*^9, 
   3.9296357454427843`*^9}},ExpressionUUID->"ac9a0bbe-760b-4eba-bc1f-\
aa1cf147307d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"E0", ",", "V0"}], "}"}], "=", 
   RowBox[{"FermionModes", "[", 
    RowBox[{"L", ",", "U", ",", "J", ",", "K"}], "]"}]}], ";", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"E0", ",", 
    RowBox[{"Joined", "->", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9300606643409348`*^9, 3.9300606646689463`*^9}},
 CellLabel->"In[71]:=",ExpressionUUID->"03a0d7ee-9b00-4cd0-baaf-e38ed7dece63"],

Cell["\<\
List the energies of the 10 lowest-energy fermion eigenmodes; notice that \
there is only one low-energy eigenmode very close to zero energy.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.9292038103249035`*^9, 3.929203811012282*^9}, 
   3.92920392822003*^9, {3.9295445556181602`*^9, 3.9295445635519485`*^9}, {
   3.9295482445059586`*^9, 3.9295482678533382`*^9}, {3.92954830694427*^9, 
   3.92954830897657*^9}, {3.9295484152004833`*^9, 3.9295484160009127`*^9}, {
   3.929548455890264*^9, 3.9295484697484255`*^9}, {3.9296338188095207`*^9, 
   3.929633899759164*^9}, 3.929635400544541*^9, {3.9296357507070246`*^9, 
   3.9296357530503583`*^9}},ExpressionUUID->"857a7d1b-5d52-4b30-8b61-\
a2202ce2fec2"],

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"E0", ",", 
   RowBox[{"-", "10"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.929633838257975*^9, 3.9296338435536084`*^9}},
 CellLabel->"In[72]:=",ExpressionUUID->"2d77df09-21f1-4c77-bc39-46789c479c5d"],

Cell["\<\
Plot the real-space wave function of the low-energy fermion eigenmode; notice \
that the wave function is localized to small regions around the two fluxes \
with a well-defined complex phase difference between the two regions.\
\>", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.9292038103249035`*^9, 3.929203811012282*^9}, 
   3.92920392822003*^9, {3.9295445556181602`*^9, 3.9295445635519485`*^9}, {
   3.9295482445059586`*^9, 3.9295482678533382`*^9}, {3.92954830694427*^9, 
   3.92954830897657*^9}, {3.9295484152004833`*^9, 3.9295484160009127`*^9}, {
   3.929548455890264*^9, 3.9295484697484255`*^9}, {3.9296354326156106`*^9, 
   3.9296355014745626`*^9}, {3.9296355482128882`*^9, 
   3.9296356083239365`*^9}, {3.929635757627406*^9, 
   3.929635758096046*^9}},ExpressionUUID->"171861f7-e454-43bf-9db5-\
2dfcd83ceb4b"],

Cell[BoxData[
 RowBox[{"PlotMode", "[", 
  RowBox[{"L", ",", "U", ",", 
   RowBox[{"V0", "[", 
    RowBox[{"[", "m", "]"}], "]"}], ",", "600", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.929196151211184*^9, 3.929196164161397*^9}, {
   3.9291961991687975`*^9, 3.9291961996529684`*^9}, {3.9291962910377064`*^9, 
   3.9291962912095428`*^9}, 3.9291964230537047`*^9, {3.9291966628438773`*^9, 
   3.9291966692173758`*^9}, {3.9291967357185163`*^9, 
   3.9291967464192305`*^9}, {3.929196931726078*^9, 3.9291969471755686`*^9}, {
   3.929197031562135*^9, 3.9291970476833487`*^9}, {3.9291971167583838`*^9, 
   3.92919711810196*^9}, {3.92919716809021*^9, 3.929197168199562*^9}, {
   3.9291972002575607`*^9, 3.9291972486525726`*^9}, {3.929197521744528*^9, 
   3.9291975219008784`*^9}, {3.929201405721687*^9, 3.9292014077555404`*^9}, 
   3.9292015004090633`*^9, 3.929201623976847*^9, 3.929549416594572*^9, {
   3.9295494915743313`*^9, 3.92954949489958*^9}, {3.929549591195448*^9, 
   3.92954959276609*^9}, {3.9295498752995353`*^9, 3.9295498767849493`*^9}, {
   3.9295500972633667`*^9, 3.9295500985337553`*^9}, {3.9300611801956224`*^9, 
   3.9300611812266293`*^9}},
 CellLabel->"In[77]:=",ExpressionUUID->"4d70ce04-c150-4d38-95f0-bd4938df66d3"],

Cell["Confirm that the complex phase difference is \[Pi]/2.", "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292033884673667`*^9, 3.929203432785187*^9}, {
   3.92920348708479*^9, 3.929203494364482*^9}, {3.9292035337925644`*^9, 
   3.929203538572728*^9}, {3.9292038103249035`*^9, 3.929203811012282*^9}, 
   3.92920392822003*^9, {3.9295445556181602`*^9, 3.9295445635519485`*^9}, {
   3.9295482445059586`*^9, 3.9295482678533382`*^9}, {3.92954830694427*^9, 
   3.92954830897657*^9}, {3.9295484152004833`*^9, 3.9295484160009127`*^9}, {
   3.929548455890264*^9, 3.9295484697484255`*^9}, {3.9296354326156106`*^9, 
   3.9296355014745626`*^9}, {3.9296355482128882`*^9, 
   3.9296356083239365`*^9}, {3.9296356679505424`*^9, 
   3.9296357213858204`*^9}, {3.9296357709211674`*^9, 
   3.9296357719833126`*^9}},ExpressionUUID->"37d10fd2-46cb-40c1-8f14-\
8a472811a0c8"],

Cell[BoxData[
 RowBox[{"Arg", "[", 
  RowBox[{
   RowBox[{"V0", "[", 
    RowBox[{"[", 
     RowBox[{"m", ",", 
      RowBox[{"709", "+", "15"}]}], "]"}], "]"}], "/", 
   RowBox[{"V0", "[", 
    RowBox[{"[", 
     RowBox[{"m", ",", "709"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.929635619836736*^9, 3.9296356583745313`*^9}, {
  3.9300613580306273`*^9, 3.9300613618577433`*^9}},
 CellLabel->"In[78]:=",ExpressionUUID->"63ceb1f7-9d5b-4f42-adc7-4b960ac54d8e"],

Cell[TextData[StyleBox["Exercise 3: Explore how the excitation energy of the \
low-energy fermion mode changes as the distance between the two fluxes is \
reduced. Is there a clear power-law or exponential dependence?",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
   3.929203764326089*^9, 3.9292039045382557`*^9}, {3.9292039755937357`*^9, 
   3.9292039814674973`*^9}, {3.9295454772656755`*^9, 
   3.9295454957966723`*^9}, {3.9296328982035522`*^9, 
   3.9296329597516127`*^9}, {3.9296329936030006`*^9, 
   3.9296331543308907`*^9}, {3.929635779325338*^9, 3.9296358602127*^9}, 
   3.930061548876*^9},ExpressionUUID->"ecc4daf8-1f97-4f47-803e-9d0330c33a77"],

Cell[TextData[StyleBox["Exercise 4: Create four flux excitations mutually far \
away from each other. How many low-energy fermion modes are there? How do \
their real-space wave functions look like? What happens if two of the fluxes \
are moved closer to each other while the other two fluxes remain far away?",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.9292018257624416`*^9, 3.929201843805105*^9}, {
   3.9292018917158422`*^9, 3.9292024837798605`*^9}, {3.9292025208803806`*^9, 
   3.9292025523261814`*^9}, {3.929202658145142*^9, 3.9292029470771275`*^9}, {
   3.9292031389228144`*^9, 3.9292031852555866`*^9}, {3.929203267355295*^9, 
   3.929203283132844*^9}, {3.9292035195772943`*^9, 3.9292035408534174`*^9}, {
   3.929203764326089*^9, 3.9292039045382557`*^9}, {3.9292039755937357`*^9, 
   3.9292039814674973`*^9}, {3.9295454772656755`*^9, 
   3.9295454957966723`*^9}, {3.9296328982035522`*^9, 
   3.9296329597516127`*^9}, {3.9296329936030006`*^9, 3.929633397398969*^9}, {
   3.92963347295259*^9, 3.929633554324093*^9}, {3.929633590237419*^9, 
   3.929633712396319*^9}, {3.9296358722098837`*^9, 3.9296360062240157`*^9}, 
   3.9300615500789804`*^9, {3.930061726318577*^9, 3.930061728661716*^9}, {
   3.930061807268191*^9, 
   3.9300618296066628`*^9}},ExpressionUUID->"29ccaed8-911d-484e-af8c-\
02d3e10da83f"]
}, Open  ]]
},
WindowSize->{1152., 585.6},
WindowMargins->{{
  Automatic, -5.399999999999864}, {-5.399999999999977, Automatic}},
FrontEndVersion->"13.1 for Microsoft Windows (64-bit) (June 16, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"3bb6fb88-fdb5-4aaf-bc00-fe4171197181"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 164, 3, 50, "Section",ExpressionUUID->"e59f7094-0396-445a-8b16-6c020d74b19f"],
Cell[747, 27, 707, 12, 27, "Text",ExpressionUUID->"36726221-9586-4d1c-8fe5-a0003a3b7f73"],
Cell[1457, 41, 5013, 140, 222, "Input",ExpressionUUID->"32fd29f6-0588-42c9-b899-7cb1a9400ecc"],
Cell[6473, 183, 1027, 16, 45, "Text",ExpressionUUID->"96935deb-e85c-4f39-9e18-46b7dcab3483"],
Cell[7503, 201, 4381, 103, 65, "Input",ExpressionUUID->"75875ff0-dc5d-4cd7-ba8d-c3f9e2773877"],
Cell[11887, 306, 1396, 21, 63, "Text",ExpressionUUID->"211ddf56-a43e-45e2-890f-d931bba36b17"],
Cell[13286, 329, 9992, 241, 136, "Input",ExpressionUUID->"5248ee17-1150-4560-94b5-ffb6ac032b00"],
Cell[23281, 572, 1545, 23, 63, "Text",ExpressionUUID->"b81ed4c1-e517-4997-86b7-fe878998b837"],
Cell[24829, 597, 5181, 135, 222, "Input",ExpressionUUID->"fe7774af-5a43-43f3-bae3-e0114204cc42"],
Cell[30013, 734, 590, 10, 27, "Text",ExpressionUUID->"1ad187d4-4b8f-4377-bf7f-8dc0c172e5f5"],
Cell[30606, 746, 1832, 50, 79, "Input",ExpressionUUID->"7f9617a6-9f05-4145-a74f-dff6e660a68f"],
Cell[32441, 798, 1815, 28, 82, "Text",ExpressionUUID->"8454923f-b0d7-4328-83bc-e9f877c0ea8d"],
Cell[34259, 828, 11523, 274, 151, "Input",ExpressionUUID->"8bc47958-9619-4af9-89f0-75ea337bfd76"],
Cell[45785, 1104, 1384, 21, 45, "Text",ExpressionUUID->"c11d83f8-c70a-4fc0-a8eb-2cba7da19751"],
Cell[47172, 1127, 3510, 76, 22, "Input",ExpressionUUID->"c2060233-8385-48ae-93c0-e3e3c2dfb4a1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50719, 1208, 226, 4, 50, "Section",ExpressionUUID->"c5e8bf5c-f625-4905-934f-25cce56d8230"],
Cell[50948, 1214, 245, 4, 27, "Text",ExpressionUUID->"02e222f6-38e0-4868-aaba-48cbda38c42f"],
Cell[51196, 1220, 526, 15, 21, "Input",ExpressionUUID->"1b8dee3f-3571-4627-90b2-16ea9b5b266f"],
Cell[51725, 1237, 256, 4, 27, "Text",ExpressionUUID->"1e2fd7b6-8754-4e1e-9e53-f83c188a2a95"],
Cell[51984, 1243, 314, 6, 21, "Input",ExpressionUUID->"25d7c490-6e53-4549-b050-1e67f3510b08"],
Cell[52301, 1251, 308, 7, 27, "Text",ExpressionUUID->"9030d8df-d7c0-4890-9a1f-4e2fababf806"],
Cell[52612, 1260, 579, 17, 21, "Input",ExpressionUUID->"ff4ff557-c832-4166-a111-95b0e6d6682d"],
Cell[53194, 1279, 606, 11, 27, "Text",ExpressionUUID->"8645ee1d-4aa8-4a20-9bbc-464f9894d3dc"],
Cell[53803, 1292, 918, 19, 21, "Input",ExpressionUUID->"6f007746-4b19-44b8-9740-67726add5c63"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54758, 1316, 310, 5, 50, "Section",ExpressionUUID->"67f4337f-ea5d-4930-b07a-a3b6778e9729"],
Cell[55071, 1323, 511, 9, 27, "Text",ExpressionUUID->"a5f41ac8-f40f-463d-820b-bf2e074eed57"],
Cell[55585, 1334, 290, 7, 21, "Input",ExpressionUUID->"d5ed3b1e-193e-49f6-aebd-377de8d40286"],
Cell[55878, 1343, 950, 15, 27, "Text",ExpressionUUID->"e8c61cc1-574c-41f3-891e-f77590b92344"],
Cell[56831, 1360, 418, 10, 21, "Input",ExpressionUUID->"9c1d65f0-b810-4261-b0fa-bd4d7eca7952"],
Cell[57252, 1372, 931, 14, 27, "Text",ExpressionUUID->"7deb112d-d4c7-48b4-b5c0-7943578cefe6"],
Cell[58186, 1388, 1351, 23, 21, "Input",ExpressionUUID->"58da5985-346e-4d1f-8d0e-4de0c8663925"],
Cell[59540, 1413, 774, 13, 27, "Text",ExpressionUUID->"2edc35fa-ac45-4ba6-9787-9d1cb6408101"],
Cell[60317, 1428, 337, 6, 21, "Input",ExpressionUUID->"4edbcad3-0509-4ca6-83a3-4ea983c546b4"],
Cell[60657, 1436, 1003, 15, 27, "Text",ExpressionUUID->"ab341fcc-4fac-4f81-b449-63bc76131aa8"],
Cell[61663, 1453, 369, 7, 21, "Input",ExpressionUUID->"e7fe2c05-2e65-49e2-90aa-5bbb1b5d3c8d"],
Cell[62035, 1462, 1112, 17, 27, "Text",ExpressionUUID->"5cdbdbe4-cb1c-47ff-bc30-5aec49511bc2"],
Cell[63150, 1481, 424, 8, 21, "Input",ExpressionUUID->"90c8a756-55fe-419e-bd0b-6c75a55c295d"],
Cell[63577, 1491, 817, 13, 27, "Text",ExpressionUUID->"d66e5edd-5b77-475f-8596-5a9e64811814"],
Cell[64397, 1506, 654, 18, 22, "Input",ExpressionUUID->"6c3c4a3c-2e07-488a-8b9f-e8d8ba474f2f"],
Cell[65054, 1526, 689, 12, 27, "Text",ExpressionUUID->"1907e137-7028-4448-b15d-77d0cc7fbd5c"],
Cell[65746, 1540, 754, 21, 25, "Input",ExpressionUUID->"78e121e0-e141-489d-add6-59eea3f8c2b3"],
Cell[66503, 1563, 656, 11, 27, "Text",ExpressionUUID->"fff8175d-d132-417a-89bf-b1cbabce2006"],
Cell[67162, 1576, 377, 8, 21, "Input",ExpressionUUID->"717024fb-5c07-4945-a7ac-b038c78dd0f4"],
Cell[67542, 1586, 880, 14, 27, "Text",ExpressionUUID->"1ea3fb47-5921-40a9-aa87-2d6945f474d6"],
Cell[68425, 1602, 555, 12, 21, "Input",ExpressionUUID->"c5e640a5-9e06-47db-8b25-2f5d6d129ce2"],
Cell[68983, 1616, 645, 11, 27, "Text",ExpressionUUID->"8739d6e1-bae3-4ec1-a981-e295c87b6e5d"],
Cell[69631, 1629, 534, 13, 21, "Input",ExpressionUUID->"fbb42755-7046-4a98-a646-187a4ecd61e3"],
Cell[70168, 1644, 628, 9, 27, "Text",ExpressionUUID->"0bbca73a-7843-432c-b3b3-1305554bc1b5"],
Cell[70799, 1655, 251, 4, 21, "Input",ExpressionUUID->"d070635d-f54f-45f9-85cb-84d8fb195ed7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71087, 1664, 333, 5, 50, "Section",ExpressionUUID->"83acea49-2575-45a9-b451-ed74c79894c7"],
Cell[71423, 1671, 610, 10, 27, "Text",ExpressionUUID->"60dfdbd1-23c5-410f-9d0f-c8db2644f8ed"],
Cell[72036, 1683, 444, 10, 21, "Input",ExpressionUUID->"eca4f02b-b24f-451d-a567-c0069ba2ae45"],
Cell[72483, 1695, 892, 14, 27, "Text",ExpressionUUID->"f2d2f08c-eb15-483e-93aa-2bc0d7c85033"],
Cell[73378, 1711, 1481, 28, 21, "Input",ExpressionUUID->"05b2b67d-e61b-4e99-a980-73bf8de8b83d"],
Cell[74862, 1741, 687, 11, 27, "Text",ExpressionUUID->"068c4c9e-4326-4a3a-8139-3f935e739352"],
Cell[75552, 1754, 335, 6, 21, "Input",ExpressionUUID->"72262ae5-9953-4eab-a0eb-1507867ee799"],
Cell[75890, 1762, 979, 15, 27, "Text",ExpressionUUID->"258e755b-918c-4bde-aed5-da5e4b62aea8"],
Cell[76872, 1779, 369, 7, 21, "Input",ExpressionUUID->"3ffed24b-9eaa-4211-9c40-8b3a9bafdcce"],
Cell[77244, 1788, 1082, 16, 27, "Text",ExpressionUUID->"a7e62060-3d89-4da1-a703-7cb2b123ce85"],
Cell[78329, 1806, 422, 8, 21, "Input",ExpressionUUID->"4124ffb2-c6cd-4a84-8b39-35d678ca7a5b"],
Cell[78754, 1816, 823, 14, 27, "Text",ExpressionUUID->"4a75a4ab-bf1d-4cd2-ab1e-aeafb7b3741a"],
Cell[79580, 1832, 654, 18, 22, "Input",ExpressionUUID->"9ee27879-655c-468f-92ad-a92f2d3f8731"],
Cell[80237, 1852, 689, 12, 27, "Text",ExpressionUUID->"956e20a7-448f-49d0-a240-9605412b667d"],
Cell[80929, 1866, 754, 21, 25, "Input",ExpressionUUID->"9f405d0f-7f35-4de0-9e4f-0509e7a80466"],
Cell[81686, 1889, 656, 11, 27, "Text",ExpressionUUID->"4e16470f-e238-4df0-89e5-25cee4d8a8c1"],
Cell[82345, 1902, 375, 8, 21, "Input",ExpressionUUID->"9de123b6-b2c0-447d-a9dc-8bf98172daf2"],
Cell[82723, 1912, 968, 15, 27, "Text",ExpressionUUID->"fbd8315c-2420-440f-9a66-addbe17ae1a5"],
Cell[83694, 1929, 617, 18, 21, "Input",ExpressionUUID->"290765c1-1ce1-43e2-ad90-760e256693b1"],
Cell[84314, 1949, 715, 12, 27, "Text",ExpressionUUID->"51a92af8-5026-41ed-a1a2-c6bf21b59503"],
Cell[85032, 1963, 251, 4, 21, "Input",ExpressionUUID->"f781716b-7c9b-4163-a8b5-7f60d66113e5"],
Cell[85286, 1969, 1181, 17, 45, "Text",ExpressionUUID->"28e266ac-a8ff-41cd-9c49-adb580a29722"],
Cell[86470, 1988, 747, 19, 79, "Input",ExpressionUUID->"dcc4ec0e-3e78-4edc-8751-d6dba2949780"],
Cell[87220, 2009, 289, 5, 21, "Input",ExpressionUUID->"55051e44-d3a7-46f5-8083-54c1a35944ad"],
Cell[87512, 2016, 214, 3, 21, "Input",ExpressionUUID->"5fb4a8ef-1b4c-4454-b97f-3ce32c2248d7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87763, 2024, 335, 5, 50, "Section",ExpressionUUID->"2028b6f9-cd15-4a3e-96c7-8644e972c8b7"],
Cell[88101, 2031, 565, 10, 27, "Text",ExpressionUUID->"ec91d0b8-69a0-42bf-9b22-36d98570921a"],
Cell[88669, 2043, 385, 8, 21, "Input",ExpressionUUID->"c1bf65e4-4854-474a-93b0-0b5e6d81ed85"],
Cell[89057, 2053, 892, 14, 27, "Text",ExpressionUUID->"2b7098bc-4908-4ebf-bfe1-0045cea3efe1"],
Cell[89952, 2069, 1479, 28, 21, "Input",ExpressionUUID->"96cfac57-baec-40de-89e3-a1b494032c9a"],
Cell[91434, 2099, 646, 9, 27, "Text",ExpressionUUID->"112eee7f-6438-4398-b451-83f7dee18de7"],
Cell[92083, 2110, 381, 6, 21, "Input",ExpressionUUID->"da8480f9-bddb-42e0-b315-3dcc67a2a671"],
Cell[92467, 2118, 983, 15, 27, "Text",ExpressionUUID->"26becea2-9894-4b74-8e62-d97cb8ab1fd1"],
Cell[93453, 2135, 371, 7, 21, "Input",ExpressionUUID->"359f362a-eca7-4b47-9b83-19dd2c75aa09"],
Cell[93827, 2144, 1079, 16, 27, "Text",ExpressionUUID->"93ee3494-5506-4c73-93f0-5c24a382d38c"],
Cell[94909, 2162, 420, 8, 21, "Input",ExpressionUUID->"66220f66-b82c-4283-a078-5964e57e458c"],
Cell[95332, 2172, 823, 14, 27, "Text",ExpressionUUID->"c95e7f0f-09a4-42de-bb21-5521bf3cdaf5"],
Cell[96158, 2188, 654, 18, 22, "Input",ExpressionUUID->"4ecd1453-b82b-4a3d-9529-0019af1f84e4"],
Cell[96815, 2208, 689, 12, 27, "Text",ExpressionUUID->"731f4040-98d7-488a-83ae-9ba226c322da"],
Cell[97507, 2222, 754, 21, 25, "Input",ExpressionUUID->"a8e97d92-7884-4c91-9d3e-d799116463c7"],
Cell[98264, 2245, 656, 11, 27, "Text",ExpressionUUID->"ddf84ed7-8ccd-4e68-890d-c35bcbf13672"],
Cell[98923, 2258, 375, 8, 21, "Input",ExpressionUUID->"eb93bde5-54a5-4f7d-b437-60604e9cb60d"],
Cell[99301, 2268, 968, 15, 27, "Text",ExpressionUUID->"469269bd-4666-4d82-a408-0fa872cdb97e"],
Cell[100272, 2285, 617, 18, 21, "Input",ExpressionUUID->"b5e38e0f-ec09-4f49-9056-0853dee5137f"],
Cell[100892, 2305, 830, 13, 27, "Text",ExpressionUUID->"9dfa97ca-3b4c-40fd-95de-73f17181ff0e"],
Cell[101725, 2320, 251, 4, 21, "Input",ExpressionUUID->"5dfde632-8a10-4c5d-bf82-ec9445c61e88"],
Cell[101979, 2326, 1051, 15, 27, "Text",ExpressionUUID->"d8ea0d5a-4b7e-4eff-ad01-0bfea570f789"],
Cell[103033, 2343, 912, 14, 27, "Text",ExpressionUUID->"3e2062a4-ffa9-4e9e-ac53-8d8256bac86c"],
Cell[103948, 2359, 672, 20, 21, "Input",ExpressionUUID->"f6395340-b23b-4510-8fd4-2ef62ab72a0e"],
Cell[104623, 2381, 946, 15, 27, "Text",ExpressionUUID->"ac9a0bbe-760b-4eba-bc1f-aa1cf147307d"],
Cell[105572, 2398, 451, 11, 21, "Input",ExpressionUUID->"03a0d7ee-9b00-4cd0-baaf-e38ed7dece63"],
Cell[106026, 2411, 1154, 17, 27, "Text",ExpressionUUID->"857a7d1b-5d52-4b30-8b61-a2202ce2fec2"],
Cell[107183, 2430, 248, 5, 21, "Input",ExpressionUUID->"2d77df09-21f1-4c77-bc39-46789c479c5d"],
Cell[107434, 2437, 1269, 19, 27, "Text",ExpressionUUID->"171861f7-e454-43bf-9db5-2dfcd83ceb4b"],
Cell[108706, 2458, 1236, 19, 21, "Input",ExpressionUUID->"4d70ce04-c150-4d38-95f0-bd4938df66d3"],
Cell[109945, 2479, 1146, 16, 27, "Text",ExpressionUUID->"37d10fd2-46cb-40c1-8f14-8a472811a0c8"],
Cell[111094, 2497, 473, 12, 21, "Input",ExpressionUUID->"63ceb1f7-9d5b-4f42-adc7-4b960ac54d8e"],
Cell[111570, 2511, 1028, 14, 27, "Text",ExpressionUUID->"ecc4daf8-1f97-4f47-803e-9d0330c33a77"],
Cell[112601, 2527, 1328, 19, 45, "Text",ExpressionUUID->"29ccaed8-911d-484e-af8c-02d3e10da83f"]
}, Open  ]]
}
]
*)

